diff --git a/test/Makefile.in b/test/Makefile.in
index 4bb5149..9bebc6b 100644
--- a/test/Makefile.in
+++ b/test/Makefile.in
@@ -26,7 +26,6 @@ src/common.o: src/common.c
 # when executed from psql, just runs the binary.
 src/%-test sql/%.sql: src/%-test.c src/common.o
 	$(CC) $(CFLAGS) $(LDFLAGS) src/$*-test.c src/common.o -o src/$*-test -lodbc
-	echo "\! ./src/$*-test" > sql/$*.sql
 
 EXTRA_CLEAN = $(TESTBINS) $(TESTSQLS) src/common.o
 
diff --git a/test/README.txt b/test/README.txt
index 80c9fac..546cc02 100644
--- a/test/README.txt
+++ b/test/README.txt
@@ -1,8 +1,5 @@
 This directory contains a regression test suite for the psqlODBC driver.
 
-The Makefile is written for Unix-like systems, there is no script to run the
-tests on Windows at the moment.
-
 Prerequisites
 -------------
 
@@ -10,13 +7,16 @@ To run the regression tests, you must have a PostgreSQL server running and
 accepting connections at port 5432. You must have the PostgreSQL server
 binaries, including the regression test driver pg_regress, in your $PATH.
 
-By default, the regression tests use the driver built from the parent directory,
-../.libs/psqlodbcw.so, for the tests. You can edit odbcinst.ini in this
-directory to test a different version.
+By default in Linux, the regression tests use the driver built from the
+parent directory, ../.libs/psqlodbcw.so, for the tests. You can edit
+odbcinst.ini in this directory to test a different version.
 
 Running the tests
 -----------------
 
+Linux
+=====
+
 To run the test suite, type:
 
   make installcheck
@@ -25,12 +25,37 @@ The PostgreSQL username used for the test is determined by the normal ODBC /
 libpq rules. You can set the PGUSER environment variable or .pgpass to
 override.
 
+Windows
+=======
+
+To run the test suite, you need first to register a driver version in the
+Windows Registry in this path. First, edit win_registry_key.reg with your
+own path directing to the ODBC library that will be tested with the regression
+tests.
+
+Then type this command in a command prompt to open the registry manager:
+
+  regedit.exe
+
+And finally import win_registry_key.reg to register the development ODBC
+driver.
+
+The Windows test suite makes use of environment variable PG_BIN to find the
+location of pg_regress and the location of the binaries of PostgreSQL that
+are passed to it. So be sure to set it accordingly.
+
+Then type the following commands to run the tests:
+
+  nmake /f win.mak
+  nmake /f win.mak installcheck
+
 Development
 -----------
 
 To add a test, add a *-test.c file to src/ directory, using one of the
 existing tests as example. Also add the test to the TESTS list in the Makefile,
-and create an expected output file in expected/ directory.
+add an entry in win.mak, then create an expected output file in output/
+directory as well as a input file in input/ directory to launch the test.
 
 The current test suite only tests a small fraction of the codebase. Whenever
 you add a new feature, or fix a non-trivial bug, please add a test case to
diff --git a/test/expected/.gitignore b/test/expected/.gitignore
new file mode 100644
index 0000000..e8f6d7a
--- /dev/null
+++ b/test/expected/.gitignore
@@ -0,0 +1,2 @@
+*.out
+!sampletables.out
diff --git a/test/expected/alter.out b/test/expected/alter.out
deleted file mode 100644
index c44486e..0000000
--- a/test/expected/alter.out
+++ /dev/null
@@ -1,7 +0,0 @@
-\! ./src/alter-test
-connected
-Result set metadata:
-t: VARCHAR(40) digits: 0, nullable
-Result set metadata:
-t: VARCHAR(80) digits: 0, nullable
-disconnecting
diff --git a/test/expected/arraybinding.out b/test/expected/arraybinding.out
deleted file mode 100644
index 53700ce..0000000
--- a/test/expected/arraybinding.out
+++ /dev/null
@@ -1,30 +0,0 @@
-\! ./src/arraybinding-test
-connected
-Parameter	Status
-Result set:
-10000
-Result set:
-0	columnwise 0
-1	columnwise 1
-100	columnwise 100
-9999	columnwise 9999
-Parameter	Status
-Fetching result sets for array bound (5 results expected)
-1: Result set:
-columnwise 100
-2: Result set:
-columnwise 101
-3: Result set:
-columnwise 102
-4: Result set:
-columnwise 103
-5: Result set:
-columnwise 104
-Number of rows in table:
-Result set:
-9995
-Result set:
-0	columnwise 0
-1	columnwise 1
-9999	columnwise 9999
-disconnecting
diff --git a/test/expected/bindcol.out b/test/expected/bindcol.out
deleted file mode 100644
index 840c75a..0000000
--- a/test/expected/bindcol.out
+++ /dev/null
@@ -1,7 +0,0 @@
-\! ./src/bindcol-test
-connected
-Result set:
-1 foo
-2 bar
-3 foobar
-disconnecting
diff --git a/test/expected/boolsaschar.out b/test/expected/boolsaschar.out
deleted file mode 100644
index 566dd50..0000000
--- a/test/expected/boolsaschar.out
+++ /dev/null
@@ -1,17 +0,0 @@
-\! ./src/boolsaschar-test
-connected
-Result set metadata:
-id: INTEGER(10) digits: 0, nullable
-t: VARCHAR(5) digits: 0, nullable
-b: VARCHAR(5) digits: 0, nullable
-Result set:
-2	yes	1
-Result set metadata:
-id: INTEGER(10) digits: 0, nullable
-t: VARCHAR(5) digits: 0, nullable
-b: VARCHAR(5) digits: 0, nullable
-Result set:
-1	yeah	1
-2	yes	1
-3	true	1
-disconnecting
diff --git a/test/expected/catalogfunctions.out b/test/expected/catalogfunctions.out
deleted file mode 100644
index 402cf4b..0000000
--- a/test/expected/catalogfunctions.out
+++ /dev/null
@@ -1,197 +0,0 @@
-\! ./src/catalogfunctions-test
-connected
-Check for SQLTypeInfo
-Result set metadata:
-TYPE_NAME: VARCHAR(128) digits: 0, nullable
-DATA_TYPE: SMALLINT(5) digits: 0, nullable
-PRECISION: INTEGER(10) digits: 0, nullable
-LITERAL_PREFIX: VARCHAR(128) digits: 0, nullable
-LITERAL_SUFFIX: VARCHAR(128) digits: 0, nullable
-CREATE_PARAMS: VARCHAR(128) digits: 0, nullable
-NULLABLE: SMALLINT(5) digits: 0, nullable
-CASE_SENSITIVE: SMALLINT(5) digits: 0, nullable
-SEARCHABLE: SMALLINT(5) digits: 0, nullable
-UNSIGNED_ATTRIBUTE: SMALLINT(5) digits: 0, nullable
-MONEY: SMALLINT(5) digits: 0, nullable
-AUTO_INCREMENT: SMALLINT(5) digits: 0, nullable
-LOCAL_TYPE_NAME: VARCHAR(128) digits: 0, nullable
-MINIMUM_SCALE: SMALLINT(5) digits: 0, nullable
-MAXIMUM_SCALE: SMALLINT(5) digits: 0, nullable
-SQL_DATA_TYPE: SMALLINT(5) digits: 0, nullable
-SQL_DATETIME_SUB: SMALLINT(5) digits: 0, nullable
-NUM_PREC_RADIX: INTEGER(10) digits: 0, nullable
-INTERVAL_PRECISION: SMALLINT(5) digits: 0, nullable
-Result set:
-varchar	12	255	'	'	max. length	1	1	3	NULL	0	NULL	NULL	NULL	NULL	12	NULL	NULL	0
-Check for SQLTables
-Result set metadata:
-TABLE_QUALIFIER: VARCHAR(128) digits: 0, nullable
-TABLE_OWNER: VARCHAR(128) digits: 0, nullable
-TABLE_NAME: VARCHAR(128) digits: 0, nullable
-TABLE_TYPE: VARCHAR(128) digits: 0, nullable
-REMARKS: VARCHAR(254) digits: 0, nullable
-Result set:
-contrib_regression	public	booltab	TABLE	
-contrib_regression	public	byteatab	TABLE	
-contrib_regression	public	intervaltable	TABLE	
-contrib_regression	public	testtab1	TABLE	
-contrib_regression	public	testtab_fk	TABLE	
-Check for SQLColumns
-Result set metadata:
-TABLE_QUALIFIER: VARCHAR(128) digits: 0, nullable
-TABLE_OWNER: VARCHAR(128) digits: 0, nullable
-TABLE_NAME: VARCHAR(128) digits: 0, nullable
-COLUMN_NAME: VARCHAR(128) digits: 0, nullable
-DATA_TYPE: SMALLINT(5) digits: 0, nullable
-TYPE_NAME: VARCHAR(128) digits: 0, nullable
-PRECISION: INTEGER(10) digits: 0, nullable
-LENGTH: INTEGER(10) digits: 0, nullable
-SCALE: SMALLINT(5) digits: 0, nullable
-RADIX: SMALLINT(5) digits: 0, nullable
-NULLABLE: SMALLINT(5) digits: 0, nullable
-REMARKS: VARCHAR(254) digits: 0, nullable
-COLUMN_DEF: VARCHAR(254) digits: 0, nullable
-SQL_DATA_TYPE: SMALLINT(5) digits: 0, nullable
-SQL_DATETIME_SUB: SMALLINT(5) digits: 0, nullable
-CHAR_OCTET_LENGTH: INTEGER(10) digits: 0, nullable
-ORDINAL_POSITION: INTEGER(10) digits: 0, nullable
-IS_NULLABLE: VARCHAR(254) digits: 0, nullable
-DISPLAY_SIZE: INTEGER(10) digits: 0, nullable
-FIELD_TYPE: INTEGER(10) digits: 0, nullable
-AUTO_INCREMENT: INTEGER(10) digits: 0, nullable
-PHYSICAL NUMBER: SMALLINT(5) digits: 0, nullable
-TABLE OID: INTEGER(10) digits: 0, nullable
-BASE TYPEID: INTEGER(10) digits: 0, nullable
-TYPMOD: INTEGER(10) digits: 0, nullable
-Result set:
-contrib_regression	public	booltab	id	4	int4
-contrib_regression	public	booltab	t	12	varchar
-contrib_regression	public	booltab	b	12	bool
-contrib_regression	public	byteatab	id	4	int4
-contrib_regression	public	byteatab	t	-3	bytea
-contrib_regression	public	intervaltable	id	4	int4
-contrib_regression	public	intervaltable	iv	12	interval
-contrib_regression	public	intervaltable	d	12	varchar
-contrib_regression	public	testtab1	id	4	int4
-contrib_regression	public	testtab1	t	12	varchar
-contrib_regression	public	testtab1_pkey	id	4	int4
-contrib_regression	public	testtab_fk	id	4	int4
-contrib_regression	public	testtab_fk	t	12	varchar
-Check for SQLSpecialColumns
-Result set metadata:
-SCOPE: SMALLINT(5) digits: 0, nullable
-COLUMN_NAME: VARCHAR(128) digits: 0, nullable
-DATA_TYPE: SMALLINT(5) digits: 0, nullable
-TYPE_NAME: VARCHAR(128) digits: 0, nullable
-PRECISION: INTEGER(10) digits: 0, nullable
-LENGTH: INTEGER(10) digits: 0, nullable
-SCALE: SMALLINT(5) digits: 0, nullable
-PSEUDO_COLUMN: SMALLINT(5) digits: 0, nullable
-Result set:
-NULL	xmin	4	xid	10	4	0	2
-Check for SQLStatistics
-Result set metadata:
-TABLE_QUALIFIER: VARCHAR(128) digits: 0, nullable
-TABLE_OWNER: VARCHAR(128) digits: 0, nullable
-TABLE_NAME: VARCHAR(128) digits: 0, nullable
-NON_UNIQUE: SMALLINT(5) digits: 0, nullable
-INDEX_QUALIFIER: VARCHAR(128) digits: 0, nullable
-INDEX_NAME: VARCHAR(128) digits: 0, nullable
-TYPE: SMALLINT(5) digits: 0, nullable
-SEQ_IN_INDEX: SMALLINT(5) digits: 0, nullable
-COLUMN_NAME: VARCHAR(128) digits: 0, nullable
-COLLATION: CHAR(1) digits: 0, nullable
-CARDINALITY: INTEGER(10) digits: 0, nullable
-PAGES: INTEGER(10) digits: 0, nullable
-FILTER_CONDITION: VARCHAR(128) digits: 0, nullable
-Result set:
-contrib_regression	public	testtab1	0	public	testtab1_pkey	3	1	id	A	NULL	NULL	NULL
-Check for SQLPrimaryKeys
-Result set metadata:
-TABLE_QUALIFIER: VARCHAR(128) digits: 0, nullable
-TABLE_OWNER: VARCHAR(128) digits: 0, nullable
-TABLE_NAME: VARCHAR(128) digits: 0, nullable
-COLUMN_NAME: VARCHAR(128) digits: 0, nullable
-KEY_SEQ: SMALLINT(5) digits: 0, nullable
-PK_NAME: VARCHAR(128) digits: 0, nullable
-Result set:
-contrib_regression	public	testtab1	id	1	testtab1_pkey
-Check for SQLForeignKeys
-Result set metadata:
-pktable_cat: VARCHAR(64) digits: 0, nullable
-pktable_schem: VARCHAR(64) digits: 0, not nullable
-pktable_name: VARCHAR(64) digits: 0, not nullable
-pkcolumn_name: VARCHAR(64) digits: 0, not nullable
-fktable_cat: VARCHAR(64) digits: 0, nullable
-fktable_schem: VARCHAR(64) digits: 0, not nullable
-fktable_name: VARCHAR(64) digits: 0, not nullable
-fkcolumn_name: VARCHAR(64) digits: 0, not nullable
-key_seq: SMALLINT(5) digits: 0, nullable
-update_rule: SMALLINT(5) digits: 0, nullable
-delete_rule: SMALLINT(5) digits: 0, nullable
-fk_name: VARCHAR(64) digits: 0, not nullable
-pk_name: VARCHAR(64) digits: 0, not nullable
-deferrablity: SMALLINT(5) digits: 0, nullable
-Result set:
-contrib_regression	public	testtab1	id	contrib_regression	public	testtab_fk	id	1	3	3	testtab_fk_id_fkey	testtab1_pkey	7
-Check for SQLProcedures
-Result set metadata:
-procedure_cat: VARCHAR(255) digits: 0, nullable
-procedure_schem: VARCHAR(64) digits: 0, not nullable
-procedure_name: VARCHAR(64) digits: 0, not nullable
-num_input_params: VARCHAR(255) digits: 0, nullable
-num_output_params: VARCHAR(255) digits: 0, nullable
-num_result_sets: VARCHAR(255) digits: 0, nullable
-remarks: VARCHAR(255) digits: 0, nullable
-procedure_type: SMALLINT(5) digits: 0, nullable
-Result set:
-	public	simple_add					2
-Check for SQLProcedureColumns
-Result set metadata:
-PROCEDURE_CAT: VARCHAR(128) digits: 0, nullable
-PROCEDUR_SCHEM: VARCHAR(128) digits: 0, nullable
-PROCEDURE_NAME: VARCHAR(128) digits: 0, nullable
-COLUMN_NAME: VARCHAR(128) digits: 0, nullable
-COLUMN_TYPE: SMALLINT(5) digits: 0, nullable
-DATA_TYPE: SMALLINT(5) digits: 0, nullable
-TYPE_NAME: VARCHAR(128) digits: 0, nullable
-COLUMN_SIZE: INTEGER(10) digits: 0, nullable
-BUFFER_LENGTH: INTEGER(10) digits: 0, nullable
-DECIMAL_DIGITS: SMALLINT(5) digits: 0, nullable
-NUM_PREC_RADIX: SMALLINT(5) digits: 0, nullable
-NULLABLE: SMALLINT(5) digits: 0, nullable
-REMARKS: VARCHAR(128) digits: 0, nullable
-COLUMN_DEF: VARCHAR(128) digits: 0, nullable
-SQL_DATA_TYPE: SMALLINT(5) digits: 0, nullable
-SQL_DATETIME_SUB: SMALLINT(5) digits: 0, nullable
-CHAR_OCTET_LENGTH: INTEGER(10) digits: 0, nullable
-ORDINAL_POSITION: INTEGER(10) digits: 0, nullable
-IS_NULLABLE: VARCHAR(128) digits: 0, nullable
-Result set:
-contrib_regression	public	simple_add		1	4	int4	10	4	0	10	2	NULL	NULL	4	NULL	NULL	1	
-contrib_regression	public	simple_add		1	4	int4	10	4	0	10	2	NULL	NULL	4	NULL	NULL	2	
-contrib_regression	public	simple_add		4	4	int4	10	4	0	10	2	NULL	NULL	4	NULL	NULL	3	
-Check for SQLTablePrivileges
-Result set metadata:
-TABLE_CAT: VARCHAR(128) digits: 0, nullable
-TABLE_SCHEM: VARCHAR(128) digits: 0, nullable
-TABLE_NAME: VARCHAR(128) digits: 0, nullable
-GRANTOR: VARCHAR(128) digits: 0, nullable
-GRANTEE: VARCHAR(128) digits: 0, nullable
-PRIVILEGE: VARCHAR(128) digits: 0, nullable
-IS_GRANTABLE: VARCHAR(128) digits: 0, nullable
-Result set:
-contrib_regression	public	testtab1	_SYSTEM	INSERT	YES
-contrib_regression	public	testtab1	_SYSTEM	SELECT	YES
-contrib_regression	public	testtab1	_SYSTEM	UPDATE	YES
-contrib_regression	public	testtab1	_SYSTEM	DELETE	YES
-contrib_regression	public	testtab1	_SYSTEM	REFERENCES	YES
-contrib_regression	public	testtab1	_SYSTEM	INSERT	YES
-contrib_regression	public	testtab1	_SYSTEM	SELECT	YES
-contrib_regression	public	testtab1	_SYSTEM	UPDATE	YES
-contrib_regression	public	testtab1	_SYSTEM	DELETE	YES
-contrib_regression	public	testtab1	_SYSTEM	REFERENCES	YES
-Result set:
-contrib_regression	public	testtab1	TABLE	
-contrib_regression	public	testtab_fk	TABLE	
-disconnecting
diff --git a/test/expected/commands.out b/test/expected/commands.out
deleted file mode 100644
index 58058c3..0000000
--- a/test/expected/commands.out
+++ /dev/null
@@ -1,8 +0,0 @@
-\! ./src/commands-test
-connected
-Testing VACUUM with SQLExecDirect...
-Testing VACUUM with SQLPrepare/SQLExecute...
-Disabling autocommit...
-Testing VACUUM with SQLExecDirect...
-Testing VACUUM with SQLPrepare/SQLExecute...
-disconnecting
diff --git a/test/expected/connect.out b/test/expected/connect.out
deleted file mode 100644
index 3762ffe..0000000
--- a/test/expected/connect.out
+++ /dev/null
@@ -1,3 +0,0 @@
-\! ./src/connect-test
-connected
-disconnecting
diff --git a/test/expected/cte.out b/test/expected/cte.out
deleted file mode 100644
index 01103aa..0000000
--- a/test/expected/cte.out
+++ /dev/null
@@ -1,33 +0,0 @@
-\! ./src/cte-test
-connected
-Result set:
-1	foo1
-2	foo2
-3	foo3
-4	foo4
-5	foo5
-6	foo6
-7	foo7
-8	foo8
-9	foo9
-10	foo10
-Result set:
-1	foo1
-2	foo2
-disconnecting
-connected
-Result set:
-1	foo1
-2	foo2
-3	foo3
-4	foo4
-5	foo5
-6	foo6
-7	foo7
-8	foo8
-9	foo9
-10	foo10
-Result set:
-1	foo1
-2	foo2
-disconnecting
diff --git a/test/expected/cursors.out b/test/expected/cursors.out
deleted file mode 100644
index f289998..0000000
--- a/test/expected/cursors.out
+++ /dev/null
@@ -1,19 +0,0 @@
-\! ./src/cursors-test
-connected
-SQL_CURSOR_COMMIT_BEHAVIOR: SQL_CB_PRESERVE
-SQL_CURSOR_ROLLBACK_BEHAVIOR: SQL_CB_PRESERVE
-
-foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
-Fetched 3210 rows altogether
-
-foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 
-Commit
-foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
-Fetched 3210 rows altogether
-
-foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 
-Rollback
-foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
-Fetched 3210 rows altogether
-
-disconnecting
diff --git a/test/expected/cursors_1.out b/test/expected/cursors_1.out
deleted file mode 100644
index 7096200..0000000
--- a/test/expected/cursors_1.out
+++ /dev/null
@@ -1,19 +0,0 @@
-\! ./src/cursors-test
-connected
-SQL_CURSOR_COMMIT_BEHAVIOR: SQL_CB_PRESERVE
-SQL_CURSOR_ROLLBACK_BEHAVIOR: SQL_CB_CLOSE
-
-foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
-Fetched 3210 rows altogether
-
-foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 
-Commit
-foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
-Fetched 3210 rows altogether
-
-foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 
-Rollback
-SQLFetch failed with HY010 (which probably means that the cursor was closed at commit/rollback)
-Fetched 10 rows altogether
-
-disconnecting
diff --git a/test/expected/cvtnulldate.out b/test/expected/cvtnulldate.out
deleted file mode 100644
index f02f312..0000000
--- a/test/expected/cvtnulldate.out
+++ /dev/null
@@ -1,5 +0,0 @@
-\! ./src/cvtnulldate-test
-connected
-Result set:
-1
-disconnecting
diff --git a/test/expected/dataatexecution.out b/test/expected/dataatexecution.out
deleted file mode 100644
index 9adc1c9..0000000
--- a/test/expected/dataatexecution.out
+++ /dev/null
@@ -1,12 +0,0 @@
-\! ./src/dataatexecution-test
-connected
-Result set:
-2
-3
-Parameter	Status
-Fetching result sets for array bound (2 results expected)
-1: Result set:
-4
-2: Result set:
-5
-disconnecting
diff --git a/test/expected/deprecated.out b/test/expected/deprecated.out
deleted file mode 100644
index 3c35c7c..0000000
--- a/test/expected/deprecated.out
+++ /dev/null
@@ -1,31 +0,0 @@
-\! ./src/deprecated-test
-Check for SQLAllocEnv
-Check for SQLAllocConnect
-Check for SQLAllocStmt
-Check for SQLSetConnectOption
-Check for SQLGetConnectOption
-Access type is: read-write
-Check for SQLError
-Error check: ERROR: relation "table_not_here" does not exist;
-Error while executing the query
-Check for SQLSetParam
-Result set:
-100
-Check for SQLGetStmtOption
-Cursor type is: forward
-Check for SQLSetStmtOption
-Cursor type is: static
-Check for SQLSetScrollOptions
-Cursor type is: forward
-Check for SQLColAttributes
-Column 1: foo
-Column 2: bar
-Check for SQLParamOptions
-Status of execution
-Check for SQLFreeStmt
-Check for SQLFreeConnect
-Check for SQLFreeEnv
-connected
-Check for SQLTransact
-Result set:
-disconnecting
diff --git a/test/expected/diagnostic.out b/test/expected/diagnostic.out
deleted file mode 100644
index 3e8487b..0000000
--- a/test/expected/diagnostic.out
+++ /dev/null
@@ -1,15 +0,0 @@
-\! ./src/diagnostic-test
-connected
-SQLExecDirect
-42601=ERROR: syntax error at or near "broken";
-Error while executing the query
-get same message again
-42601=ERROR: syntax error at or near "broken";
-Error while executing the query
-killing connection...
-57P01=FATAL: terminating connection due to administrator command;
-Error while executing the query
-SQLGetDiagRec on connection says:
-57P01=FATAL: terminating connection due to administrator command
-SQLGetDiagRec called again:
-57P01=FATAL: terminating connection due to administrator command
diff --git a/test/expected/error-rollback.out b/test/expected/error-rollback.out
deleted file mode 100644
index 436a328..0000000
--- a/test/expected/error-rollback.out
+++ /dev/null
@@ -1,33 +0,0 @@
-\! ./src/error-rollback-test
-Test for rollback protocol 0
-connected
-Executing query that will succeed
-Executing query that will fail
-Failed to execute statement
-22P02=ERROR: invalid input syntax for integer: "foo"
-Rolling back with SQLEndTran
-Executing query that will succeed
-Result set:
-1
-disconnecting
-Test for rollback protocol 1
-connected
-Executing query that will succeed
-Executing query that will fail
-Failed to execute statement
-22P02=ERROR: invalid input syntax for integer: "foo"
-Executing query that will succeed
-Result set:
-1
-disconnecting
-Test for rollback protocol 2
-connected
-Executing query that will succeed
-Executing query that will fail
-Failed to execute statement
-22P02=ERROR: invalid input syntax for integer: "foo"
-Executing query that will succeed
-Result set:
-1
-1
-disconnecting
diff --git a/test/expected/getresult.out b/test/expected/getresult.out
deleted file mode 100644
index 0cc92e8..0000000
--- a/test/expected/getresult.out
+++ /dev/null
@@ -1,10 +0,0 @@
-\! ./src/getresult-test
-connected
-Result set:
-varcharcol: foo
-integercol: 123
-intervalyears: 10
-intervalmonths: 11
-intervaldays: 12
-bogus long string as interval: 0
-disconnecting
diff --git a/test/expected/insertreturning.out b/test/expected/insertreturning.out
deleted file mode 100644
index c01fa29..0000000
--- a/test/expected/insertreturning.out
+++ /dev/null
@@ -1,303 +0,0 @@
-\! ./src/insertreturning-test
-connected
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 0
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 1
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 2
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 3
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 4
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 5
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 6
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 7
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 8
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 9
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 10
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 11
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 12
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 13
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 14
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 15
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 16
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 17
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 18
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 19
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 20
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 21
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 22
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 23
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 24
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 25
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 26
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 27
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 28
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 29
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 30
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 31
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 32
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 33
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 34
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 35
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 36
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 37
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 38
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 39
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 40
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 41
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 42
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 43
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 44
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 45
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 46
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 47
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 48
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 49
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 50
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 51
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 52
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 53
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 54
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 55
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 56
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 57
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 58
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 59
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 60
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 61
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 62
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 63
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 64
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 65
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 66
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 67
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 68
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 69
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 70
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 71
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 72
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 73
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 74
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 75
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 76
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 77
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 78
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 79
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 80
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 81
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 82
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 83
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 84
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 85
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 86
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 87
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 88
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 89
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 90
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 91
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 92
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 93
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 94
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 95
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 96
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 97
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 98
-# of result cols before SQLExecute: 1, after: 1
-Result set:
-foobar 99
-disconnecting
diff --git a/test/expected/lfconversion.out b/test/expected/lfconversion.out
deleted file mode 100644
index ca4776c..0000000
--- a/test/expected/lfconversion.out
+++ /dev/null
@@ -1,18 +0,0 @@
-\! ./src/lfconversion-test
-connected
-reading to char buffer...
-strlen 22, SQLGetData claims 22
-
-reading to char buffer, with truncation...
-strlen 9, SQLGetData claims 22
-
-reading to SQLWCHAR buffer...
-len 22 chars, SQLGetData claims 44 bytes
-
-reading to SQLWCHAR buffer, with truncation...
-len 4 chars, SQLGetData claims 44 bytes
-
-reading to SQLWCHAR buffer, with LF->CR+LF conversion causing truncation...
-len 20 chars, SQLGetData claims 44 bytes
-
-disconnecting
diff --git a/test/expected/multistmt.out b/test/expected/multistmt.out
deleted file mode 100644
index 6b3166f..0000000
--- a/test/expected/multistmt.out
+++ /dev/null
@@ -1,24 +0,0 @@
-\! ./src/multistmt-test
-connected
---1 Result set:
-1
---2 Result set:
-2
---1 Result set:
-1
---2 Result set:
-foo	bar
---3 Result set:
-3
---4 Result set:
-4
---1 Result set:
-foo	bar
---2 Result set:
-foobar
-# of result cols: 3
---1 Result set:
-first result set	1	foo
---2 Result set:
-second result set	bar
-disconnecting
diff --git a/test/expected/notice.out b/test/expected/notice.out
deleted file mode 100644
index ad449aa..0000000
--- a/test/expected/notice.out
+++ /dev/null
@@ -1,7 +0,0 @@
-\! ./src/notice-test
-connected
-got SUCCESS_WITH_INFO
-00000=NOTICE: test notice: foo
-got SUCCESS_WITH_INFO
-00000=
-disconnecting
diff --git a/test/expected/params.out b/test/expected/params.out
deleted file mode 100644
index 63c96be..0000000
--- a/test/expected/params.out
+++ /dev/null
@@ -1,17 +0,0 @@
-\! ./src/params-test
-connected
-# of result cols: 2
-Result set:
-1	0102030405060708
-
-Testing SQLBindParameter with SQLExecDirect...
-Result set:
-foo
-bar
-
-Testing SQLDescribeParam...
-Param 1: type INTEGER; size 10; dec digits -1; nullable
-# of result cols: 2
-Result set:
-3	foobar
-disconnecting
diff --git a/test/expected/positioned-update.out b/test/expected/positioned-update.out
deleted file mode 100644
index e8ebb87..0000000
--- a/test/expected/positioned-update.out
+++ /dev/null
@@ -1,21 +0,0 @@
-\! ./src/positioned-update-test
-connected
-Creating test table pos_update_test
-Opening a cursor for update, and fetching 10 rows
-1	1
-2	2
-3	3
-4	4
-5	5
-Updating result set
-Result set:
-1	1
-2	2
-3	3
-4	4
-105	5
-7	7
-8	8
-9	9
-10	10
-disconnecting
diff --git a/test/expected/prepare.out b/test/expected/prepare.out
deleted file mode 100644
index 71a9d7f..0000000
--- a/test/expected/prepare.out
+++ /dev/null
@@ -1,117 +0,0 @@
-\! ./src/prepare-test
-connected
-# of result cols: 2
-Result set:
-2	bar
-Result set:
-3	foobar
-inserting bytea values... 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 done!
-Now reading them back...
-Result set:
-4000	4000
-4001	4001
-4002	4002
-4003	4003
-4004	4004
-4005	4005
-4006	4006
-4007	4007
-4008	4008
-4009	4009
-4010	4010
-4011	4011
-4012	4012
-4013	4013
-4014	4014
-4015	4015
-4016	4016
-4017	4017
-4018	4018
-4019	4019
-4020	4020
-4021	4021
-4022	4022
-4023	4023
-4024	4024
-4025	4025
-4026	4026
-4027	4027
-4028	4028
-4029	4029
-4030	4030
-4031	4031
-4032	4032
-4033	4033
-4034	4034
-4035	4035
-4036	4036
-4037	4037
-4038	4038
-4039	4039
-4040	4040
-4041	4041
-4042	4042
-4043	4043
-4044	4044
-4045	4045
-4046	4046
-4047	4047
-4048	4048
-4049	4049
-4050	4050
-4051	4051
-4052	4052
-4053	4053
-4054	4054
-4055	4055
-4056	4056
-4057	4057
-4058	4058
-4059	4059
-4060	4060
-4061	4061
-4062	4062
-4063	4063
-4064	4064
-4065	4065
-4066	4066
-4067	4067
-4068	4068
-4069	4069
-4070	4070
-4071	4071
-4072	4072
-4073	4073
-4074	4074
-4075	4075
-4076	4076
-4077	4077
-4078	4078
-4079	4079
-4080	4080
-4081	4081
-4082	4082
-4083	4083
-4084	4084
-4085	4085
-4086	4086
-4087	4087
-4088	4088
-4089	4089
-4090	4090
-4091	4091
-4092	4092
-4093	4093
-4094	4094
-4095	4095
-4096	4096
-4097	4097
-4098	4098
-4099	4099
-Result set:
-1	@ 1 day	one day
-2	@ 10 secs	ten secs
-# of result cols: 2
-Result set:
-2	bar
-disconnecting
diff --git a/test/expected/quotes.out b/test/expected/quotes.out
deleted file mode 100644
index e8560b0..0000000
--- a/test/expected/quotes.out
+++ /dev/null
@@ -1,23 +0,0 @@
-\! ./src/quotes-test
-connected
-Result set:
-Result set:
-foo
-param'quote
-Result set:
-foo
-param\backslash
-Result set:
-foo
-ends with backslash\
-Result set:
-Result set:
-foo
-param'quote
-Result set:
-foo
-param\backslash
-Result set:
-foo
-ends with backslash\
-disconnecting
diff --git a/test/expected/select.out b/test/expected/select.out
deleted file mode 100644
index 2fe6fe3..0000000
--- a/test/expected/select.out
+++ /dev/null
@@ -1,8 +0,0 @@
-\! ./src/select-test
-connected
-Result set:
-1
-2
-Result set:
-1	2	3	4	5	6	7	8	9	10	11	12	13	14	15	16	17	18	19	20	21	22	23	24	25	26	27	28	29	30	31	32	33	34	35	36	37	38	39	40	41	42	43	44	45	46	47	48	49	50	51	52	53	54	55	56	57	58	59	60	61	62	63	64	65	66	67	68	69	70	71	72	73	74	75	76	77	78	79	80	81	82	83	84	85	86	87	88	89	90	91	92	93	94	95	96	97	98	99	100	101	102	103	104	105	106	107	108	109	110	111	112	113	114	115	116	117	118	119	120	121	122	123	124	125	126	127	128	129	130	131	132	133	134	135	136	137	138	139	140	141	142	143	144	145	146	147	148	149	150	151	152	153	154	155	156	157	158	159	160	161	162	163	164	165	166	167	168	169	170	171	172	173	174	175	176	177	178	179	180	181	182	183	184	185	186	187	188	189	190	191	192	193	194	195	196	197	198	199	200	201	202	203	204	205	206	207	208	209	210	211	212	213	214	215	216	217	218	219	220	221	222	223	224	225	226	227	228	229	230	231	232	233	234	235	236	237	238	239	240	241	242	243	244	245	246	247	248	249	250	251	252	253	254	255	256	257	258	259	260	261	262	263	264	265	266	267	268	269	270	271	272	273	274	275	276	277	278	279	280	281	282	283	284	285	286	287	288	289	290	291	292	293	294	295	296	297	298	299	300	301	302	303	304	305	306	307	308	309	310	311	312	313	314	315	316	317	318	319	320	321	322	323	324	325	326	327	328	329	330	331	332	333	334	335	336	337	338	339	340	341	342	343	344	345	346	347	348	349	350	351	352	353	354	355	356	357	358	359	360	361	362	363	364	365	366	367	368	369	370	371	372	373	374	375	376	377	378	379	380	381	382	383	384	385	386	387	388	389	390	391	392	393	394	395	396	397	398	399	400	401	402	403	404	405	406	407	408	409	410	411	412	413	414	415	416	417	418	419	420	421	422	423	424	425	426	427	428	429	430	431	432	433	434	435	436	437	438	439	440	441	442	443	444	445	446	447	448	449	450	451	452	453	454	455	456	457	458	459	460	461	462	463	464	465	466	467	468	469	470	471	472	473	474	475	476	477	478	479	480	481	482	483	484	485	486	487	488	489	490	491	492	493	494	495	496	497	498	499	500	501	502	503	504	505	506	507	508	509	510	511	512	513	514	515	516	517	518	519	520	521	522	523	524	525	526	527	528	529	530	531	532	533	534	535	536	537	538	539	540	541	542	543	544	545	546	547	548	549	550	551	552	553	554	555	556	557	558	559	560	561	562	563	564	565	566	567	568	569	570	571	572	573	574	575	576	577	578	579	580	581	582	583	584	585	586	587	588	589	590	591	592	593	594	595	596	597	598	599	600	601	602	603	604	605	606	607	608	609	610	611	612	613	614	615	616	617	618	619	620	621	622	623	624	625	626	627	628	629	630	631	632	633	634	635	636	637	638	639	640	641	642	643	644	645	646	647	648	649	650	651	652	653	654	655	656	657	658	659	660	661	662	663	664	665	666	667	668	669	670	671	672	673	674	675	676	677	678	679	680	681	682	683	684	685	686	687	688	689	690	691	692	693	694	695	696	697	698	699	700	701	702	703	704	705	706	707	708	709	710	711	712	713	714	715	716	717	718	719	720	721	722	723	724	725	726	727	728	729	730	731	732	733	734	735	736	737	738	739	740	741	742	743	744	745	746	747	748	749	750	751	752	753	754	755	756	757	758	759	760	761	762	763	764	765	766	767	768	769	770	771	772	773	774	775	776	777	778	779	780	781	782	783	784	785	786	787	788	789	790	791	792	793	794	795	796	797	798	799	800	801	802	803	804	805	806	807	808	809	810	811	812	813	814	815	816	817	818	819	820	821	822	823	824	825	826	827	828	829	830	831	832	833	834	835	836	837	838	839	840	841	842	843	844	845	846	847	848	849	850	851	852	853	854	855	856	857	858	859	860	861	862	863	864	865	866	867	868	869	870	871	872	873	874	875	876	877	878	879	880	881	882	883	884	885	886	887	888	889	890	891	892	893	894	895	896	897	898	899	900	901	902	903	904	905	906	907	908	909	910	911	912	913	914	915	916	917	918	919	920	921	922	923	924	925	926	927	928	929	930	931	932	933	934	935	936	937	938	939	940	941	942	943	944	945	946	947	948	949	950	951	952	953	954	955	956	957	958	959	960	961	962	963	964	965	966	967	968	969	970	971	972	973	974	975	976	977	978	979	980	981	982	983	984	985	986	987	988	989	990	991	992	993	994	995	996	997	998	999	1000	1001	1002	1003	1004	1005	1006	1007	1008	1009	1010	1011	1012	1013	1014	1015	1016	1017	1018	1019	1020	1021	1022	1023	1024	1025	1026	1027	1028	1029	1030	1031	1032	1033	1034	1035	1036	1037	1038	1039	1040	1041	1042	1043	1044	1045	1046	1047	1048	1049	1050	1051	1052	1053	1054	1055	1056	1057	1058	1059	1060	1061	1062	1063	1064	1065	1066	1067	1068	1069	1070	1071	1072	1073	1074	1075	1076	1077	1078	1079	1080	1081	1082	1083	1084	1085	1086	1087	1088	1089	1090	1091	1092	1093	1094	1095	1096	1097	1098	1099	1100	1101	1102	1103	1104	1105	1106	1107	1108	1109	1110	1111	1112	1113	1114	1115	1116	1117	1118	1119	1120	1121	1122	1123	1124	1125	1126	1127	1128	1129	1130	1131	1132	1133	1134	1135	1136	1137	1138	1139	1140	1141	1142	1143	1144	1145	1146	1147	1148	1149	1150	1151	1152	1153	1154	1155	1156	1157	1158	1159	1160	1161	1162	1163	1164	1165	1166	1167	1168	1169	1170	1171	1172	1173	1174	1175	1176	1177	1178	1179	1180	1181	1182	1183	1184	1185	1186	1187	1188	1189	1190	1191	1192	1193	1194	1195	1196	1197	1198	1199	1200	1201	1202	1203	1204	1205	1206	1207	1208	1209	1210	1211	1212	1213	1214	1215	1216	1217	1218	1219	1220	1221	1222	1223	1224	1225	1226	1227	1228	1229	1230	1231	1232	1233	1234	1235	1236	1237	1238	1239	1240	1241	1242	1243	1244	1245	1246	1247	1248	1249	1250	1251	1252	1253	1254	1255	1256	1257	1258	1259	1260	1261	1262	1263	1264	1265	1266	1267	1268	1269	1270	1271	1272	1273	1274	1275	1276	1277	1278	1279	1280	1281	1282	1283	1284	1285	1286	1287	1288	1289	1290	1291	1292	1293	1294	1295	1296	1297	1298	1299	1300	1301	1302	1303	1304	1305	1306	1307	1308	1309	1310	1311	1312	1313	1314	1315	1316	1317	1318	1319	1320	1321	1322	1323	1324	1325	1326	1327	1328	1329	1330	1331	1332	1333	1334	1335	1336	1337	1338	1339	1340	1341	1342	1343	1344	1345	1346	1347	1348	1349	1350	1351	1352	1353	1354	1355	1356	1357	1358	1359	1360	1361	1362	1363	1364	1365	1366	1367	1368	1369	1370	1371	1372	1373	1374	1375	1376	1377	1378	1379	1380	1381	1382	1383	1384	1385	1386	1387	1388	1389	1390	1391	1392	1393	1394	1395	1396	1397	1398	1399	1400	1401	1402	1403	1404	1405	1406	1407	1408	1409	1410	1411	1412	1413	1414	1415	1416	1417	1418	1419	1420	1421	1422	1423	1424	1425	1426	1427	1428	1429	1430	1431	1432	1433	1434	1435	1436	1437	1438	1439	1440	1441	1442	1443	1444	1445	1446	1447	1448	1449	1450	1451	1452	1453	1454	1455	1456	1457	1458	1459	1460	1461	1462	1463	1464	1465	1466	1467	1468	1469	1470	1471	1472	1473	1474	1475	1476	1477	1478	1479	1480	1481	1482	1483	1484	1485	1486	1487	1488	1489	1490	1491	1492	1493	1494	1495	1496	1497	1498	1499	1500	1501	1502	1503	1504	1505	1506	1507	1508	1509	1510	1511	1512	1513	1514	1515	1516	1517	1518	1519	1520	1521	1522	1523	1524	1525	1526	1527	1528	1529	1530	1531	1532	1533	1534	1535	1536	1537	1538	1539	1540	1541	1542	1543	1544	1545	1546	1547	1548	1549	1550	1551	1552	1553	1554	1555	1556	1557	1558	1559	1560	1561	1562	1563	1564	1565	1566	1567	1568	1569	1570	1571	1572	1573	1574	1575	1576	1577	1578	1579	1580	1581	1582	1583	1584	1585	1586	1587	1588	1589	1590	1591	1592	1593	1594	1595	1596	1597	1598	1599	1600
-disconnecting
diff --git a/test/expected/stmthandles.out b/test/expected/stmthandles.out
deleted file mode 100644
index ebcccf7..0000000
--- a/test/expected/stmthandles.out
+++ /dev/null
@@ -1,70 +0,0 @@
-\! ./src/stmthandles-test
-connected
-10 statements allocated...
-20 statements allocated...
-30 statements allocated...
-40 statements allocated...
-50 statements allocated...
-60 statements allocated...
-70 statements allocated...
-80 statements allocated...
-90 statements allocated...
-100 statements allocated...
-10 statements executed...
-20 statements executed...
-30 statements executed...
-40 statements executed...
-50 statements executed...
-60 statements executed...
-70 statements executed...
-80 statements executed...
-90 statements executed...
-100 statements executed...
-Result set:
-stmt no 1
-Result set:
-stmt no 11
-Result set:
-stmt no 21
-Result set:
-stmt no 31
-Result set:
-stmt no 41
-Result set:
-stmt no 51
-Result set:
-stmt no 61
-Result set:
-stmt no 71
-Result set:
-stmt no 81
-Result set:
-stmt no 91
-
-Testing interleaving operations on multiple prepared statements
-# of result cols: 1
-# of result cols: 2
-# of result cols: 3
-# of result cols: 4
-# of result cols: 5
-Result set:
-stmt no 0
-stmt no 0
-stmt no 0
-Result set:
-stmt no 1	col 0
-stmt no 1	col 0
-stmt no 1	col 0
-Result set:
-stmt no 2	col 0	col 1
-stmt no 2	col 0	col 1
-stmt no 2	col 0	col 1
-Result set:
-stmt no 3	col 0	col 1	col 2
-stmt no 3	col 0	col 1	col 2
-stmt no 3	col 0	col 1	col 2
-Result set:
-stmt no 4	col 0	col 1	col 2	col 3
-stmt no 4	col 0	col 1	col 2	col 3
-stmt no 4	col 0	col 1	col 2	col 3
-disconnecting
diff --git a/test/input/alter.source b/test/input/alter.source
new file mode 100644
index 0000000..d9ea317
--- /dev/null
+++ b/test/input/alter.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/alter-test
diff --git a/test/input/arraybinding.source b/test/input/arraybinding.source
new file mode 100644
index 0000000..37e9812
--- /dev/null
+++ b/test/input/arraybinding.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/arraybinding-test
diff --git a/test/input/bindcol.source b/test/input/bindcol.source
new file mode 100644
index 0000000..4e997ca
--- /dev/null
+++ b/test/input/bindcol.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/bindcol-test
diff --git a/test/input/boolsaschar.source b/test/input/boolsaschar.source
new file mode 100644
index 0000000..1cb1ea5
--- /dev/null
+++ b/test/input/boolsaschar.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/boolsaschar-test
diff --git a/test/input/catalogfunctions.source b/test/input/catalogfunctions.source
new file mode 100644
index 0000000..62bfe98
--- /dev/null
+++ b/test/input/catalogfunctions.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/catalogfunctions-test
diff --git a/test/input/commands.source b/test/input/commands.source
new file mode 100644
index 0000000..cb36a99
--- /dev/null
+++ b/test/input/commands.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/commands-test
diff --git a/test/input/connect.source b/test/input/connect.source
new file mode 100644
index 0000000..2227239
--- /dev/null
+++ b/test/input/connect.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/connect-test
diff --git a/test/input/cte.source b/test/input/cte.source
new file mode 100644
index 0000000..02778c4
--- /dev/null
+++ b/test/input/cte.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/cte-test
diff --git a/test/input/cursors.source b/test/input/cursors.source
new file mode 100644
index 0000000..99e1df9
--- /dev/null
+++ b/test/input/cursors.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/cursors-test
diff --git a/test/input/cvtnulldate.source b/test/input/cvtnulldate.source
new file mode 100644
index 0000000..adddc36
--- /dev/null
+++ b/test/input/cvtnulldate.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/cvtnulldate-test
diff --git a/test/input/dataatexecution.source b/test/input/dataatexecution.source
new file mode 100644
index 0000000..f6dc8c8
--- /dev/null
+++ b/test/input/dataatexecution.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/dataatexecution-test
diff --git a/test/input/deprecated.source b/test/input/deprecated.source
new file mode 100644
index 0000000..2beaf1b
--- /dev/null
+++ b/test/input/deprecated.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/deprecated-test
diff --git a/test/input/diagnostic.source b/test/input/diagnostic.source
new file mode 100644
index 0000000..a65842a
--- /dev/null
+++ b/test/input/diagnostic.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/diagnostic-test
diff --git a/test/input/error-rollback.source b/test/input/error-rollback.source
new file mode 100644
index 0000000..1996963
--- /dev/null
+++ b/test/input/error-rollback.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/error-rollback-test
diff --git a/test/input/getresult.source b/test/input/getresult.source
new file mode 100644
index 0000000..d4c8320
--- /dev/null
+++ b/test/input/getresult.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/getresult-test
diff --git a/test/input/insertreturning.source b/test/input/insertreturning.source
new file mode 100644
index 0000000..14953b3
--- /dev/null
+++ b/test/input/insertreturning.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/insertreturning-test
diff --git a/test/input/lfconversion.source b/test/input/lfconversion.source
new file mode 100644
index 0000000..588d181
--- /dev/null
+++ b/test/input/lfconversion.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/lfconversion-test
diff --git a/test/input/multistmt.source b/test/input/multistmt.source
new file mode 100644
index 0000000..3a4f11e
--- /dev/null
+++ b/test/input/multistmt.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/multistmt-test
diff --git a/test/input/notice.source b/test/input/notice.source
new file mode 100644
index 0000000..d97bef6
--- /dev/null
+++ b/test/input/notice.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/notice-test
diff --git a/test/input/params.source b/test/input/params.source
new file mode 100644
index 0000000..1fd3344
--- /dev/null
+++ b/test/input/params.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/params-test
diff --git a/test/input/positioned-update.source b/test/input/positioned-update.source
new file mode 100644
index 0000000..422d98c
--- /dev/null
+++ b/test/input/positioned-update.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/positioned-update-test
diff --git a/test/input/prepare.source b/test/input/prepare.source
new file mode 100644
index 0000000..adfee5f
--- /dev/null
+++ b/test/input/prepare.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/prepare-test
diff --git a/test/input/quotes.source b/test/input/quotes.source
new file mode 100644
index 0000000..cf6bd12
--- /dev/null
+++ b/test/input/quotes.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/quotes-test
diff --git a/test/input/select.source b/test/input/select.source
new file mode 100644
index 0000000..2f804eb
--- /dev/null
+++ b/test/input/select.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/select-test
diff --git a/test/input/stmthandles.source b/test/input/stmthandles.source
new file mode 100644
index 0000000..3bc0168
--- /dev/null
+++ b/test/input/stmthandles.source
@@ -0,0 +1 @@
+\! @abs_srcdir@/src/stmthandles-test
diff --git a/test/output/alter.source b/test/output/alter.source
new file mode 100644
index 0000000..8e44ce5
--- /dev/null
+++ b/test/output/alter.source
@@ -0,0 +1,7 @@
+\! @abs_srcdir@/src/alter-test
+connected
+Result set metadata:
+t: VARCHAR(40) digits: 0, nullable
+Result set metadata:
+t: VARCHAR(80) digits: 0, nullable
+disconnecting
diff --git a/test/output/alter_1.source b/test/output/alter_1.source
new file mode 100644
index 0000000..10bee01
--- /dev/null
+++ b/test/output/alter_1.source
@@ -0,0 +1,7 @@
+\! @abs_srcdir@/src/alter-test
+connected
+Result set metadata:
+t: WVARCHAR(40) digits: 0, nullable
+Result set metadata:
+t: WVARCHAR(80) digits: 0, nullable
+disconnecting
diff --git a/test/output/arraybinding.source b/test/output/arraybinding.source
new file mode 100644
index 0000000..1c09e0b
--- /dev/null
+++ b/test/output/arraybinding.source
@@ -0,0 +1,30 @@
+\! @abs_srcdir@/src/arraybinding-test
+connected
+Parameter	Status
+Result set:
+10000
+Result set:
+0	columnwise 0
+1	columnwise 1
+100	columnwise 100
+9999	columnwise 9999
+Parameter	Status
+Fetching result sets for array bound (5 results expected)
+1: Result set:
+columnwise 100
+2: Result set:
+columnwise 101
+3: Result set:
+columnwise 102
+4: Result set:
+columnwise 103
+5: Result set:
+columnwise 104
+Number of rows in table:
+Result set:
+9995
+Result set:
+0	columnwise 0
+1	columnwise 1
+9999	columnwise 9999
+disconnecting
diff --git a/test/output/bindcol.source b/test/output/bindcol.source
new file mode 100644
index 0000000..9d438c1
--- /dev/null
+++ b/test/output/bindcol.source
@@ -0,0 +1,7 @@
+\! @abs_srcdir@/src/bindcol-test
+connected
+Result set:
+1 foo
+2 bar
+3 foobar
+disconnecting
diff --git a/test/output/boolsaschar.source b/test/output/boolsaschar.source
new file mode 100644
index 0000000..8ca7bbb
--- /dev/null
+++ b/test/output/boolsaschar.source
@@ -0,0 +1,17 @@
+\! @abs_srcdir@/src/boolsaschar-test
+connected
+Result set metadata:
+id: INTEGER(10) digits: 0, nullable
+t: VARCHAR(5) digits: 0, nullable
+b: VARCHAR(5) digits: 0, nullable
+Result set:
+2	yes	1
+Result set metadata:
+id: INTEGER(10) digits: 0, nullable
+t: VARCHAR(5) digits: 0, nullable
+b: VARCHAR(5) digits: 0, nullable
+Result set:
+1	yeah	1
+2	yes	1
+3	true	1
+disconnecting
diff --git a/test/output/boolsaschar_1.source b/test/output/boolsaschar_1.source
new file mode 100644
index 0000000..ff8324b
--- /dev/null
+++ b/test/output/boolsaschar_1.source
@@ -0,0 +1,17 @@
+\! @abs_srcdir@/src/boolsaschar-test
+connected
+Result set metadata:
+id: INTEGER(10) digits: 0, nullable
+t: WVARCHAR(5) digits: 0, nullable
+b: VARCHAR(5) digits: 0, nullable
+Result set:
+2	yes	1
+Result set metadata:
+id: INTEGER(10) digits: 0, nullable
+t: WVARCHAR(5) digits: 0, nullable
+b: VARCHAR(5) digits: 0, nullable
+Result set:
+1	yeah	1
+2	yes	1
+3	true	1
+disconnecting
diff --git a/test/output/catalogfunctions.source b/test/output/catalogfunctions.source
new file mode 100644
index 0000000..e1cb5f8
--- /dev/null
+++ b/test/output/catalogfunctions.source
@@ -0,0 +1,197 @@
+\! @abs_srcdir@/src/catalogfunctions-test
+connected
+Check for SQLTypeInfo
+Result set metadata:
+TYPE_NAME: VARCHAR(128) digits: 0, nullable
+DATA_TYPE: SMALLINT(5) digits: 0, nullable
+PRECISION: INTEGER(10) digits: 0, nullable
+LITERAL_PREFIX: VARCHAR(128) digits: 0, nullable
+LITERAL_SUFFIX: VARCHAR(128) digits: 0, nullable
+CREATE_PARAMS: VARCHAR(128) digits: 0, nullable
+NULLABLE: SMALLINT(5) digits: 0, nullable
+CASE_SENSITIVE: SMALLINT(5) digits: 0, nullable
+SEARCHABLE: SMALLINT(5) digits: 0, nullable
+UNSIGNED_ATTRIBUTE: SMALLINT(5) digits: 0, nullable
+MONEY: SMALLINT(5) digits: 0, nullable
+AUTO_INCREMENT: SMALLINT(5) digits: 0, nullable
+LOCAL_TYPE_NAME: VARCHAR(128) digits: 0, nullable
+MINIMUM_SCALE: SMALLINT(5) digits: 0, nullable
+MAXIMUM_SCALE: SMALLINT(5) digits: 0, nullable
+SQL_DATA_TYPE: SMALLINT(5) digits: 0, nullable
+SQL_DATETIME_SUB: SMALLINT(5) digits: 0, nullable
+NUM_PREC_RADIX: INTEGER(10) digits: 0, nullable
+INTERVAL_PRECISION: SMALLINT(5) digits: 0, nullable
+Result set:
+varchar	12	255	'	'	max. length	1	1	3	NULL	0	NULL	NULL	NULL	NULL	12	NULL	NULL	0
+Check for SQLTables
+Result set metadata:
+TABLE_QUALIFIER: VARCHAR(128) digits: 0, nullable
+TABLE_OWNER: VARCHAR(128) digits: 0, nullable
+TABLE_NAME: VARCHAR(128) digits: 0, nullable
+TABLE_TYPE: VARCHAR(128) digits: 0, nullable
+REMARKS: VARCHAR(254) digits: 0, nullable
+Result set:
+contrib_regression	public	booltab	TABLE	
+contrib_regression	public	byteatab	TABLE	
+contrib_regression	public	intervaltable	TABLE	
+contrib_regression	public	testtab1	TABLE	
+contrib_regression	public	testtab_fk	TABLE	
+Check for SQLColumns
+Result set metadata:
+TABLE_QUALIFIER: VARCHAR(128) digits: 0, nullable
+TABLE_OWNER: VARCHAR(128) digits: 0, nullable
+TABLE_NAME: VARCHAR(128) digits: 0, nullable
+COLUMN_NAME: VARCHAR(128) digits: 0, nullable
+DATA_TYPE: SMALLINT(5) digits: 0, nullable
+TYPE_NAME: VARCHAR(128) digits: 0, nullable
+PRECISION: INTEGER(10) digits: 0, nullable
+LENGTH: INTEGER(10) digits: 0, nullable
+SCALE: SMALLINT(5) digits: 0, nullable
+RADIX: SMALLINT(5) digits: 0, nullable
+NULLABLE: SMALLINT(5) digits: 0, nullable
+REMARKS: VARCHAR(254) digits: 0, nullable
+COLUMN_DEF: VARCHAR(254) digits: 0, nullable
+SQL_DATA_TYPE: SMALLINT(5) digits: 0, nullable
+SQL_DATETIME_SUB: SMALLINT(5) digits: 0, nullable
+CHAR_OCTET_LENGTH: INTEGER(10) digits: 0, nullable
+ORDINAL_POSITION: INTEGER(10) digits: 0, nullable
+IS_NULLABLE: VARCHAR(254) digits: 0, nullable
+DISPLAY_SIZE: INTEGER(10) digits: 0, nullable
+FIELD_TYPE: INTEGER(10) digits: 0, nullable
+AUTO_INCREMENT: INTEGER(10) digits: 0, nullable
+PHYSICAL NUMBER: SMALLINT(5) digits: 0, nullable
+TABLE OID: INTEGER(10) digits: 0, nullable
+BASE TYPEID: INTEGER(10) digits: 0, nullable
+TYPMOD: INTEGER(10) digits: 0, nullable
+Result set:
+contrib_regression	public	booltab	id	4	int4
+contrib_regression	public	booltab	t	12	varchar
+contrib_regression	public	booltab	b	12	bool
+contrib_regression	public	byteatab	id	4	int4
+contrib_regression	public	byteatab	t	-3	bytea
+contrib_regression	public	intervaltable	id	4	int4
+contrib_regression	public	intervaltable	iv	12	interval
+contrib_regression	public	intervaltable	d	12	varchar
+contrib_regression	public	testtab1	id	4	int4
+contrib_regression	public	testtab1	t	12	varchar
+contrib_regression	public	testtab1_pkey	id	4	int4
+contrib_regression	public	testtab_fk	id	4	int4
+contrib_regression	public	testtab_fk	t	12	varchar
+Check for SQLSpecialColumns
+Result set metadata:
+SCOPE: SMALLINT(5) digits: 0, nullable
+COLUMN_NAME: VARCHAR(128) digits: 0, nullable
+DATA_TYPE: SMALLINT(5) digits: 0, nullable
+TYPE_NAME: VARCHAR(128) digits: 0, nullable
+PRECISION: INTEGER(10) digits: 0, nullable
+LENGTH: INTEGER(10) digits: 0, nullable
+SCALE: SMALLINT(5) digits: 0, nullable
+PSEUDO_COLUMN: SMALLINT(5) digits: 0, nullable
+Result set:
+NULL	xmin	4	xid	10	4	0	2
+Check for SQLStatistics
+Result set metadata:
+TABLE_QUALIFIER: VARCHAR(128) digits: 0, nullable
+TABLE_OWNER: VARCHAR(128) digits: 0, nullable
+TABLE_NAME: VARCHAR(128) digits: 0, nullable
+NON_UNIQUE: SMALLINT(5) digits: 0, nullable
+INDEX_QUALIFIER: VARCHAR(128) digits: 0, nullable
+INDEX_NAME: VARCHAR(128) digits: 0, nullable
+TYPE: SMALLINT(5) digits: 0, nullable
+SEQ_IN_INDEX: SMALLINT(5) digits: 0, nullable
+COLUMN_NAME: VARCHAR(128) digits: 0, nullable
+COLLATION: CHAR(1) digits: 0, nullable
+CARDINALITY: INTEGER(10) digits: 0, nullable
+PAGES: INTEGER(10) digits: 0, nullable
+FILTER_CONDITION: VARCHAR(128) digits: 0, nullable
+Result set:
+contrib_regression	public	testtab1	0	public	testtab1_pkey	3	1	id	A	NULL	NULL	NULL
+Check for SQLPrimaryKeys
+Result set metadata:
+TABLE_QUALIFIER: VARCHAR(128) digits: 0, nullable
+TABLE_OWNER: VARCHAR(128) digits: 0, nullable
+TABLE_NAME: VARCHAR(128) digits: 0, nullable
+COLUMN_NAME: VARCHAR(128) digits: 0, nullable
+KEY_SEQ: SMALLINT(5) digits: 0, nullable
+PK_NAME: VARCHAR(128) digits: 0, nullable
+Result set:
+contrib_regression	public	testtab1	id	1	testtab1_pkey
+Check for SQLForeignKeys
+Result set metadata:
+pktable_cat: VARCHAR(64) digits: 0, nullable
+pktable_schem: VARCHAR(64) digits: 0, not nullable
+pktable_name: VARCHAR(64) digits: 0, not nullable
+pkcolumn_name: VARCHAR(64) digits: 0, not nullable
+fktable_cat: VARCHAR(64) digits: 0, nullable
+fktable_schem: VARCHAR(64) digits: 0, not nullable
+fktable_name: VARCHAR(64) digits: 0, not nullable
+fkcolumn_name: VARCHAR(64) digits: 0, not nullable
+key_seq: SMALLINT(5) digits: 0, nullable
+update_rule: SMALLINT(5) digits: 0, nullable
+delete_rule: SMALLINT(5) digits: 0, nullable
+fk_name: VARCHAR(64) digits: 0, not nullable
+pk_name: VARCHAR(64) digits: 0, not nullable
+deferrablity: SMALLINT(5) digits: 0, nullable
+Result set:
+contrib_regression	public	testtab1	id	contrib_regression	public	testtab_fk	id	1	3	3	testtab_fk_id_fkey	testtab1_pkey	7
+Check for SQLProcedures
+Result set metadata:
+procedure_cat: VARCHAR(255) digits: 0, nullable
+procedure_schem: VARCHAR(64) digits: 0, not nullable
+procedure_name: VARCHAR(64) digits: 0, not nullable
+num_input_params: VARCHAR(255) digits: 0, nullable
+num_output_params: VARCHAR(255) digits: 0, nullable
+num_result_sets: VARCHAR(255) digits: 0, nullable
+remarks: VARCHAR(255) digits: 0, nullable
+procedure_type: SMALLINT(5) digits: 0, nullable
+Result set:
+	public	simple_add					2
+Check for SQLProcedureColumns
+Result set metadata:
+PROCEDURE_CAT: VARCHAR(128) digits: 0, nullable
+PROCEDUR_SCHEM: VARCHAR(128) digits: 0, nullable
+PROCEDURE_NAME: VARCHAR(128) digits: 0, nullable
+COLUMN_NAME: VARCHAR(128) digits: 0, nullable
+COLUMN_TYPE: SMALLINT(5) digits: 0, nullable
+DATA_TYPE: SMALLINT(5) digits: 0, nullable
+TYPE_NAME: VARCHAR(128) digits: 0, nullable
+COLUMN_SIZE: INTEGER(10) digits: 0, nullable
+BUFFER_LENGTH: INTEGER(10) digits: 0, nullable
+DECIMAL_DIGITS: SMALLINT(5) digits: 0, nullable
+NUM_PREC_RADIX: SMALLINT(5) digits: 0, nullable
+NULLABLE: SMALLINT(5) digits: 0, nullable
+REMARKS: VARCHAR(128) digits: 0, nullable
+COLUMN_DEF: VARCHAR(128) digits: 0, nullable
+SQL_DATA_TYPE: SMALLINT(5) digits: 0, nullable
+SQL_DATETIME_SUB: SMALLINT(5) digits: 0, nullable
+CHAR_OCTET_LENGTH: INTEGER(10) digits: 0, nullable
+ORDINAL_POSITION: INTEGER(10) digits: 0, nullable
+IS_NULLABLE: VARCHAR(128) digits: 0, nullable
+Result set:
+contrib_regression	public	simple_add		1	4	int4	10	4	0	10	2	NULL	NULL	4	NULL	NULL	1	
+contrib_regression	public	simple_add		1	4	int4	10	4	0	10	2	NULL	NULL	4	NULL	NULL	2	
+contrib_regression	public	simple_add		4	4	int4	10	4	0	10	2	NULL	NULL	4	NULL	NULL	3	
+Check for SQLTablePrivileges
+Result set metadata:
+TABLE_CAT: VARCHAR(128) digits: 0, nullable
+TABLE_SCHEM: VARCHAR(128) digits: 0, nullable
+TABLE_NAME: VARCHAR(128) digits: 0, nullable
+GRANTOR: VARCHAR(128) digits: 0, nullable
+GRANTEE: VARCHAR(128) digits: 0, nullable
+PRIVILEGE: VARCHAR(128) digits: 0, nullable
+IS_GRANTABLE: VARCHAR(128) digits: 0, nullable
+Result set:
+contrib_regression	public	testtab1	_SYSTEM	INSERT	YES
+contrib_regression	public	testtab1	_SYSTEM	SELECT	YES
+contrib_regression	public	testtab1	_SYSTEM	UPDATE	YES
+contrib_regression	public	testtab1	_SYSTEM	DELETE	YES
+contrib_regression	public	testtab1	_SYSTEM	REFERENCES	YES
+contrib_regression	public	testtab1	_SYSTEM	INSERT	YES
+contrib_regression	public	testtab1	_SYSTEM	SELECT	YES
+contrib_regression	public	testtab1	_SYSTEM	UPDATE	YES
+contrib_regression	public	testtab1	_SYSTEM	DELETE	YES
+contrib_regression	public	testtab1	_SYSTEM	REFERENCES	YES
+Result set:
+contrib_regression	public	testtab1	TABLE	
+contrib_regression	public	testtab_fk	TABLE	
+disconnecting
diff --git a/test/output/catalogfunctions_1.source b/test/output/catalogfunctions_1.source
new file mode 100644
index 0000000..80bc754
--- /dev/null
+++ b/test/output/catalogfunctions_1.source
@@ -0,0 +1,197 @@
+\! @abs_srcdir@/src/catalogfunctions-test
+connected
+Check for SQLTypeInfo
+Result set metadata:
+TYPE_NAME: WVARCHAR(128) digits: 0, nullable
+DATA_TYPE: SMALLINT(5) digits: 0, nullable
+PRECISION: INTEGER(10) digits: 0, nullable
+LITERAL_PREFIX: WVARCHAR(128) digits: 0, nullable
+LITERAL_SUFFIX: WVARCHAR(128) digits: 0, nullable
+CREATE_PARAMS: WVARCHAR(128) digits: 0, nullable
+NULLABLE: SMALLINT(5) digits: 0, nullable
+CASE_SENSITIVE: SMALLINT(5) digits: 0, nullable
+SEARCHABLE: SMALLINT(5) digits: 0, nullable
+UNSIGNED_ATTRIBUTE: SMALLINT(5) digits: 0, nullable
+MONEY: SMALLINT(5) digits: 0, nullable
+AUTO_INCREMENT: SMALLINT(5) digits: 0, nullable
+LOCAL_TYPE_NAME: WVARCHAR(128) digits: 0, nullable
+MINIMUM_SCALE: SMALLINT(5) digits: 0, nullable
+MAXIMUM_SCALE: SMALLINT(5) digits: 0, nullable
+SQL_DATA_TYPE: SMALLINT(5) digits: 0, nullable
+SQL_DATETIME_SUB: SMALLINT(5) digits: 0, nullable
+NUM_PREC_RADIX: INTEGER(10) digits: 0, nullable
+INTERVAL_PRECISION: SMALLINT(5) digits: 0, nullable
+Result set:
+varchar	12	255	'	'	max. length	1	1	3	NULL	0	NULL	NULL	NULL	NULL	-9	NULL	NULL	0
+Check for SQLTables
+Result set metadata:
+TABLE_QUALIFIER: WVARCHAR(128) digits: 0, nullable
+TABLE_OWNER: WVARCHAR(128) digits: 0, nullable
+TABLE_NAME: WVARCHAR(128) digits: 0, nullable
+TABLE_TYPE: WVARCHAR(128) digits: 0, nullable
+REMARKS: WVARCHAR(254) digits: 0, nullable
+Result set:
+contrib_regression	public	booltab	TABLE	
+contrib_regression	public	byteatab	TABLE	
+contrib_regression	public	intervaltable	TABLE	
+contrib_regression	public	testtab1	TABLE	
+contrib_regression	public	testtab_fk	TABLE	
+Check for SQLColumns
+Result set metadata:
+TABLE_QUALIFIER: WVARCHAR(128) digits: 0, nullable
+TABLE_OWNER: WVARCHAR(128) digits: 0, nullable
+TABLE_NAME: WVARCHAR(128) digits: 0, nullable
+COLUMN_NAME: WVARCHAR(128) digits: 0, nullable
+DATA_TYPE: SMALLINT(5) digits: 0, nullable
+TYPE_NAME: WVARCHAR(128) digits: 0, nullable
+PRECISION: INTEGER(10) digits: 0, nullable
+LENGTH: INTEGER(10) digits: 0, nullable
+SCALE: SMALLINT(5) digits: 0, nullable
+RADIX: SMALLINT(5) digits: 0, nullable
+NULLABLE: SMALLINT(5) digits: 0, nullable
+REMARKS: WVARCHAR(254) digits: 0, nullable
+COLUMN_DEF: WVARCHAR(254) digits: 0, nullable
+SQL_DATA_TYPE: SMALLINT(5) digits: 0, nullable
+SQL_DATETIME_SUB: SMALLINT(5) digits: 0, nullable
+CHAR_OCTET_LENGTH: INTEGER(10) digits: 0, nullable
+ORDINAL_POSITION: INTEGER(10) digits: 0, nullable
+IS_NULLABLE: WVARCHAR(254) digits: 0, nullable
+DISPLAY_SIZE: INTEGER(10) digits: 0, nullable
+FIELD_TYPE: INTEGER(10) digits: 0, nullable
+AUTO_INCREMENT: INTEGER(10) digits: 0, nullable
+PHYSICAL NUMBER: SMALLINT(5) digits: 0, nullable
+TABLE OID: INTEGER(10) digits: 0, nullable
+BASE TYPEID: INTEGER(10) digits: 0, nullable
+TYPMOD: INTEGER(10) digits: 0, nullable
+Result set:
+contrib_regression	public	booltab	id	4	int4
+contrib_regression	public	booltab	t	12	varchar
+contrib_regression	public	booltab	b	12	bool
+contrib_regression	public	byteatab	id	4	int4
+contrib_regression	public	byteatab	t	-3	bytea
+contrib_regression	public	intervaltable	id	4	int4
+contrib_regression	public	intervaltable	iv	12	interval
+contrib_regression	public	intervaltable	d	12	varchar
+contrib_regression	public	testtab1	id	4	int4
+contrib_regression	public	testtab1	t	12	varchar
+contrib_regression	public	testtab1_pkey	id	4	int4
+contrib_regression	public	testtab_fk	id	4	int4
+contrib_regression	public	testtab_fk	t	12	varchar
+Check for SQLSpecialColumns
+Result set metadata:
+SCOPE: SMALLINT(5) digits: 0, nullable
+COLUMN_NAME: WVARCHAR(128) digits: 0, nullable
+DATA_TYPE: SMALLINT(5) digits: 0, nullable
+TYPE_NAME: WVARCHAR(128) digits: 0, nullable
+PRECISION: INTEGER(10) digits: 0, nullable
+LENGTH: INTEGER(10) digits: 0, nullable
+SCALE: SMALLINT(5) digits: 0, nullable
+PSEUDO_COLUMN: SMALLINT(5) digits: 0, nullable
+Result set:
+NULL	xmin	4	xid	10	4	0	2
+Check for SQLStatistics
+Result set metadata:
+TABLE_QUALIFIER: WVARCHAR(128) digits: 0, nullable
+TABLE_OWNER: WVARCHAR(128) digits: 0, nullable
+TABLE_NAME: WVARCHAR(128) digits: 0, nullable
+NON_UNIQUE: SMALLINT(5) digits: 0, nullable
+INDEX_QUALIFIER: WVARCHAR(128) digits: 0, nullable
+INDEX_NAME: WVARCHAR(128) digits: 0, nullable
+TYPE: SMALLINT(5) digits: 0, nullable
+SEQ_IN_INDEX: SMALLINT(5) digits: 0, nullable
+COLUMN_NAME: WVARCHAR(128) digits: 0, nullable
+COLLATION: WCHAR(1) digits: 0, nullable
+CARDINALITY: INTEGER(10) digits: 0, nullable
+PAGES: INTEGER(10) digits: 0, nullable
+FILTER_CONDITION: WVARCHAR(128) digits: 0, nullable
+Result set:
+contrib_regression	public	testtab1	0	public	testtab1_pkey	3	1	id	A	NULL	NULL	NULL
+Check for SQLPrimaryKeys
+Result set metadata:
+TABLE_QUALIFIER: WVARCHAR(128) digits: 0, nullable
+TABLE_OWNER: WVARCHAR(128) digits: 0, nullable
+TABLE_NAME: WVARCHAR(128) digits: 0, nullable
+COLUMN_NAME: WVARCHAR(128) digits: 0, nullable
+KEY_SEQ: SMALLINT(5) digits: 0, nullable
+PK_NAME: WVARCHAR(128) digits: 0, nullable
+Result set:
+contrib_regression	public	testtab1	id	1	testtab1_pkey
+Check for SQLForeignKeys
+Result set metadata:
+pktable_cat: WVARCHAR(64) digits: 0, nullable
+pktable_schem: WVARCHAR(64) digits: 0, not nullable
+pktable_name: WVARCHAR(64) digits: 0, not nullable
+pkcolumn_name: WVARCHAR(64) digits: 0, not nullable
+fktable_cat: WVARCHAR(64) digits: 0, nullable
+fktable_schem: WVARCHAR(64) digits: 0, not nullable
+fktable_name: WVARCHAR(64) digits: 0, not nullable
+fkcolumn_name: WVARCHAR(64) digits: 0, not nullable
+key_seq: SMALLINT(5) digits: 0, nullable
+update_rule: SMALLINT(5) digits: 0, nullable
+delete_rule: SMALLINT(5) digits: 0, nullable
+fk_name: WVARCHAR(64) digits: 0, not nullable
+pk_name: WVARCHAR(64) digits: 0, not nullable
+deferrablity: SMALLINT(5) digits: 0, nullable
+Result set:
+contrib_regression	public	testtab1	id	contrib_regression	public	testtab_fk	id	1	3	3	testtab_fk_id_fkey	testtab1_pkey	7
+Check for SQLProcedures
+Result set metadata:
+procedure_cat: WVARCHAR(255) digits: 0, nullable
+procedure_schem: WVARCHAR(64) digits: 0, not nullable
+procedure_name: WVARCHAR(64) digits: 0, not nullable
+num_input_params: WVARCHAR(255) digits: 0, nullable
+num_output_params: WVARCHAR(255) digits: 0, nullable
+num_result_sets: WVARCHAR(255) digits: 0, nullable
+remarks: WVARCHAR(255) digits: 0, nullable
+procedure_type: SMALLINT(5) digits: 0, nullable
+Result set:
+	public	simple_add					2
+Check for SQLProcedureColumns
+Result set metadata:
+PROCEDURE_CAT: WVARCHAR(128) digits: 0, nullable
+PROCEDUR_SCHEM: WVARCHAR(128) digits: 0, nullable
+PROCEDURE_NAME: WVARCHAR(128) digits: 0, nullable
+COLUMN_NAME: WVARCHAR(128) digits: 0, nullable
+COLUMN_TYPE: SMALLINT(5) digits: 0, nullable
+DATA_TYPE: SMALLINT(5) digits: 0, nullable
+TYPE_NAME: WVARCHAR(128) digits: 0, nullable
+COLUMN_SIZE: INTEGER(10) digits: 0, nullable
+BUFFER_LENGTH: INTEGER(10) digits: 0, nullable
+DECIMAL_DIGITS: SMALLINT(5) digits: 0, nullable
+NUM_PREC_RADIX: SMALLINT(5) digits: 0, nullable
+NULLABLE: SMALLINT(5) digits: 0, nullable
+REMARKS: WVARCHAR(128) digits: 0, nullable
+COLUMN_DEF: WVARCHAR(128) digits: 0, nullable
+SQL_DATA_TYPE: SMALLINT(5) digits: 0, nullable
+SQL_DATETIME_SUB: SMALLINT(5) digits: 0, nullable
+CHAR_OCTET_LENGTH: INTEGER(10) digits: 0, nullable
+ORDINAL_POSITION: INTEGER(10) digits: 0, nullable
+IS_NULLABLE: WVARCHAR(128) digits: 0, nullable
+Result set:
+contrib_regression	public	simple_add		1	4	int4	10	4	0	10	2	NULL	NULL	4	NULL	NULL	1	
+contrib_regression	public	simple_add		1	4	int4	10	4	0	10	2	NULL	NULL	4	NULL	NULL	2	
+contrib_regression	public	simple_add		4	4	int4	10	4	0	10	2	NULL	NULL	4	NULL	NULL	3	
+Check for SQLTablePrivileges
+Result set metadata:
+TABLE_CAT: WVARCHAR(128) digits: 0, nullable
+TABLE_SCHEM: WVARCHAR(128) digits: 0, nullable
+TABLE_NAME: WVARCHAR(128) digits: 0, nullable
+GRANTOR: WVARCHAR(128) digits: 0, nullable
+GRANTEE: WVARCHAR(128) digits: 0, nullable
+PRIVILEGE: WVARCHAR(128) digits: 0, nullable
+IS_GRANTABLE: WVARCHAR(128) digits: 0, nullable
+Result set:
+contrib_regression	public	testtab1	_SYSTEM	INSERT	YES
+contrib_regression	public	testtab1	_SYSTEM	SELECT	YES
+contrib_regression	public	testtab1	_SYSTEM	UPDATE	YES
+contrib_regression	public	testtab1	_SYSTEM	DELETE	YES
+contrib_regression	public	testtab1	_SYSTEM	REFERENCES	YES
+contrib_regression	public	testtab1	_SYSTEM	INSERT	YES
+contrib_regression	public	testtab1	_SYSTEM	SELECT	YES
+contrib_regression	public	testtab1	_SYSTEM	UPDATE	YES
+contrib_regression	public	testtab1	_SYSTEM	DELETE	YES
+contrib_regression	public	testtab1	_SYSTEM	REFERENCES	YES
+Result set:
+contrib_regression	public	testtab1	TABLE	
+contrib_regression	public	testtab_fk	TABLE	
+disconnecting
diff --git a/test/output/commands.source b/test/output/commands.source
new file mode 100644
index 0000000..954f8cd
--- /dev/null
+++ b/test/output/commands.source
@@ -0,0 +1,8 @@
+\! @abs_srcdir@/src/commands-test
+connected
+Testing VACUUM with SQLExecDirect...
+Testing VACUUM with SQLPrepare/SQLExecute...
+Disabling autocommit...
+Testing VACUUM with SQLExecDirect...
+Testing VACUUM with SQLPrepare/SQLExecute...
+disconnecting
diff --git a/test/output/connect.source b/test/output/connect.source
new file mode 100644
index 0000000..a5c2b9f
--- /dev/null
+++ b/test/output/connect.source
@@ -0,0 +1,3 @@
+\! @abs_srcdir@/src/connect-test
+connected
+disconnecting
diff --git a/test/output/cte.source b/test/output/cte.source
new file mode 100644
index 0000000..ed51c87
--- /dev/null
+++ b/test/output/cte.source
@@ -0,0 +1,33 @@
+\! @abs_srcdir@/src/cte-test
+connected
+Result set:
+1	foo1
+2	foo2
+3	foo3
+4	foo4
+5	foo5
+6	foo6
+7	foo7
+8	foo8
+9	foo9
+10	foo10
+Result set:
+1	foo1
+2	foo2
+disconnecting
+connected
+Result set:
+1	foo1
+2	foo2
+3	foo3
+4	foo4
+5	foo5
+6	foo6
+7	foo7
+8	foo8
+9	foo9
+10	foo10
+Result set:
+1	foo1
+2	foo2
+disconnecting
diff --git a/test/output/cursors.source b/test/output/cursors.source
new file mode 100644
index 0000000..1be2e24
--- /dev/null
+++ b/test/output/cursors.source
@@ -0,0 +1,19 @@
+\! @abs_srcdir@/src/cursors-test
+connected
+SQL_CURSOR_COMMIT_BEHAVIOR: SQL_CB_PRESERVE
+SQL_CURSOR_ROLLBACK_BEHAVIOR: SQL_CB_PRESERVE
+
+foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
+Fetched 3210 rows altogether
+
+foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 
+Commit
+foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
+Fetched 3210 rows altogether
+
+foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 
+Rollback
+foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
+Fetched 3210 rows altogether
+
+disconnecting
diff --git a/test/output/cursors_1.source b/test/output/cursors_1.source
new file mode 100644
index 0000000..1b601dc
--- /dev/null
+++ b/test/output/cursors_1.source
@@ -0,0 +1,19 @@
+\! @abs_srcdir@/src/cursors-test
+connected
+SQL_CURSOR_COMMIT_BEHAVIOR: SQL_CB_PRESERVE
+SQL_CURSOR_ROLLBACK_BEHAVIOR: SQL_CB_CLOSE
+
+foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
+Fetched 3210 rows altogether
+
+foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 
+Commit
+foo11 foo12 foo13 foo14 foo15 foo16 foo17 foo18 foo19 foo20 ... foo3207 foo3208 foo3209 foo3210 
+Fetched 3210 rows altogether
+
+foo1 foo2 foo3 foo4 foo5 foo6 foo7 foo8 foo9 foo10 
+Rollback
+SQLFetch failed with HY010 (which probably means that the cursor was closed at commit/rollback)
+Fetched 10 rows altogether
+
+disconnecting
diff --git a/test/output/cvtnulldate.source b/test/output/cvtnulldate.source
new file mode 100644
index 0000000..d8838a0
--- /dev/null
+++ b/test/output/cvtnulldate.source
@@ -0,0 +1,5 @@
+\! @abs_srcdir@/src/cvtnulldate-test
+connected
+Result set:
+1
+disconnecting
diff --git a/test/output/dataatexecution.source b/test/output/dataatexecution.source
new file mode 100644
index 0000000..601d431
--- /dev/null
+++ b/test/output/dataatexecution.source
@@ -0,0 +1,12 @@
+\! @abs_srcdir@/src/dataatexecution-test
+connected
+Result set:
+2
+3
+Parameter	Status
+Fetching result sets for array bound (2 results expected)
+1: Result set:
+4
+2: Result set:
+5
+disconnecting
diff --git a/test/output/deprecated.source b/test/output/deprecated.source
new file mode 100644
index 0000000..ea52c65
--- /dev/null
+++ b/test/output/deprecated.source
@@ -0,0 +1,31 @@
+\! @abs_srcdir@/src/deprecated-test
+Check for SQLAllocEnv
+Check for SQLAllocConnect
+Check for SQLAllocStmt
+Check for SQLSetConnectOption
+Check for SQLGetConnectOption
+Access type is: read-write
+Check for SQLError
+Error check: ERROR: relation "table_not_here" does not exist;
+Error while executing the query
+Check for SQLSetParam
+Result set:
+100
+Check for SQLGetStmtOption
+Cursor type is: forward
+Check for SQLSetStmtOption
+Cursor type is: static
+Check for SQLSetScrollOptions
+Cursor type is: forward
+Check for SQLColAttributes
+Column 1: foo
+Column 2: bar
+Check for SQLParamOptions
+Status of execution
+Check for SQLFreeStmt
+Check for SQLFreeConnect
+Check for SQLFreeEnv
+connected
+Check for SQLTransact
+Result set:
+disconnecting
diff --git a/test/output/diagnostic.source b/test/output/diagnostic.source
new file mode 100644
index 0000000..c7009de
--- /dev/null
+++ b/test/output/diagnostic.source
@@ -0,0 +1,15 @@
+\! @abs_srcdir@/src/diagnostic-test
+connected
+SQLExecDirect
+42601=ERROR: syntax error at or near "broken";
+Error while executing the query
+get same message again
+42601=ERROR: syntax error at or near "broken";
+Error while executing the query
+killing connection...
+57P01=FATAL: terminating connection due to administrator command;
+Error while executing the query
+SQLGetDiagRec on connection says:
+57P01=FATAL: terminating connection due to administrator command
+SQLGetDiagRec called again:
+57P01=FATAL: terminating connection due to administrator command
diff --git a/test/output/error-rollback.source b/test/output/error-rollback.source
new file mode 100644
index 0000000..6fd884b
--- /dev/null
+++ b/test/output/error-rollback.source
@@ -0,0 +1,33 @@
+\! @abs_srcdir@/src/error-rollback-test
+Test for rollback protocol 0
+connected
+Executing query that will succeed
+Executing query that will fail
+Failed to execute statement
+22P02=ERROR: invalid input syntax for integer: "foo"
+Rolling back with SQLEndTran
+Executing query that will succeed
+Result set:
+1
+disconnecting
+Test for rollback protocol 1
+connected
+Executing query that will succeed
+Executing query that will fail
+Failed to execute statement
+22P02=ERROR: invalid input syntax for integer: "foo"
+Executing query that will succeed
+Result set:
+1
+disconnecting
+Test for rollback protocol 2
+connected
+Executing query that will succeed
+Executing query that will fail
+Failed to execute statement
+22P02=ERROR: invalid input syntax for integer: "foo"
+Executing query that will succeed
+Result set:
+1
+1
+disconnecting
diff --git a/test/output/getresult.source b/test/output/getresult.source
new file mode 100644
index 0000000..a965f16
--- /dev/null
+++ b/test/output/getresult.source
@@ -0,0 +1,10 @@
+\! @abs_srcdir@/src/getresult-test
+connected
+Result set:
+varcharcol: foo
+integercol: 123
+intervalyears: 10
+intervalmonths: 11
+intervaldays: 12
+bogus long string as interval: 0
+disconnecting
diff --git a/test/output/insertreturning.source b/test/output/insertreturning.source
new file mode 100644
index 0000000..c7645c3
--- /dev/null
+++ b/test/output/insertreturning.source
@@ -0,0 +1,303 @@
+\! @abs_srcdir@/src/insertreturning-test
+connected
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 0
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 1
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 2
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 3
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 4
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 5
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 6
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 7
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 8
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 9
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 10
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 11
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 12
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 13
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 14
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 15
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 16
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 17
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 18
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 19
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 20
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 21
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 22
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 23
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 24
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 25
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 26
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 27
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 28
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 29
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 30
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 31
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 32
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 33
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 34
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 35
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 36
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 37
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 38
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 39
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 40
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 41
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 42
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 43
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 44
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 45
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 46
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 47
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 48
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 49
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 50
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 51
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 52
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 53
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 54
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 55
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 56
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 57
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 58
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 59
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 60
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 61
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 62
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 63
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 64
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 65
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 66
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 67
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 68
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 69
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 70
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 71
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 72
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 73
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 74
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 75
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 76
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 77
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 78
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 79
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 80
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 81
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 82
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 83
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 84
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 85
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 86
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 87
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 88
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 89
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 90
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 91
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 92
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 93
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 94
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 95
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 96
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 97
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 98
+# of result cols before SQLExecute: 1, after: 1
+Result set:
+foobar 99
+disconnecting
diff --git a/test/output/lfconversion.source b/test/output/lfconversion.source
new file mode 100644
index 0000000..6276a49
--- /dev/null
+++ b/test/output/lfconversion.source
@@ -0,0 +1,18 @@
+\! @abs_srcdir@/src/lfconversion-test
+connected
+reading to char buffer...
+strlen 22, SQLGetData claims 22
+
+reading to char buffer, with truncation...
+strlen 9, SQLGetData claims 22
+
+reading to SQLWCHAR buffer...
+len 22 chars, SQLGetData claims 44 bytes
+
+reading to SQLWCHAR buffer, with truncation...
+len 4 chars, SQLGetData claims 44 bytes
+
+reading to SQLWCHAR buffer, with LF->CR+LF conversion causing truncation...
+len 20 chars, SQLGetData claims 44 bytes
+
+disconnecting
diff --git a/test/output/multistmt.source b/test/output/multistmt.source
new file mode 100644
index 0000000..036159e
--- /dev/null
+++ b/test/output/multistmt.source
@@ -0,0 +1,24 @@
+\! @abs_srcdir@/src/multistmt-test
+connected
+--1 Result set:
+1
+--2 Result set:
+2
+--1 Result set:
+1
+--2 Result set:
+foo	bar
+--3 Result set:
+3
+--4 Result set:
+4
+--1 Result set:
+foo	bar
+--2 Result set:
+foobar
+# of result cols: 3
+--1 Result set:
+first result set	1	foo
+--2 Result set:
+second result set	bar
+disconnecting
diff --git a/test/output/notice.source b/test/output/notice.source
new file mode 100644
index 0000000..71e771a
--- /dev/null
+++ b/test/output/notice.source
@@ -0,0 +1,7 @@
+\! @abs_srcdir@/src/notice-test
+connected
+got SUCCESS_WITH_INFO
+00000=NOTICE: test notice: foo
+got SUCCESS_WITH_INFO
+00000=
+disconnecting
diff --git a/test/output/params.source b/test/output/params.source
new file mode 100644
index 0000000..a408047
--- /dev/null
+++ b/test/output/params.source
@@ -0,0 +1,17 @@
+\! @abs_srcdir@/src/params-test
+connected
+# of result cols: 2
+Result set:
+1	0102030405060708
+
+Testing SQLBindParameter with SQLExecDirect...
+Result set:
+foo
+bar
+
+Testing SQLDescribeParam...
+Param 1: type INTEGER; size 10; dec digits -1; nullable
+# of result cols: 2
+Result set:
+3	foobar
+disconnecting
diff --git a/test/output/positioned-update.source b/test/output/positioned-update.source
new file mode 100644
index 0000000..74e3c1d
--- /dev/null
+++ b/test/output/positioned-update.source
@@ -0,0 +1,21 @@
+\! @abs_srcdir@/src/positioned-update-test
+connected
+Creating test table pos_update_test
+Opening a cursor for update, and fetching 10 rows
+1	1
+2	2
+3	3
+4	4
+5	5
+Updating result set
+Result set:
+1	1
+2	2
+3	3
+4	4
+105	5
+7	7
+8	8
+9	9
+10	10
+disconnecting
diff --git a/test/output/prepare.source b/test/output/prepare.source
new file mode 100644
index 0000000..170265d
--- /dev/null
+++ b/test/output/prepare.source
@@ -0,0 +1,117 @@
+\! @abs_srcdir@/src/prepare-test
+connected
+# of result cols: 2
+Result set:
+2	bar
+Result set:
+3	foobar
+inserting bytea values... 4000 4001 4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 4085 4086 4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 done!
+Now reading them back...
+Result set:
+4000	4000
+4001	4001
+4002	4002
+4003	4003
+4004	4004
+4005	4005
+4006	4006
+4007	4007
+4008	4008
+4009	4009
+4010	4010
+4011	4011
+4012	4012
+4013	4013
+4014	4014
+4015	4015
+4016	4016
+4017	4017
+4018	4018
+4019	4019
+4020	4020
+4021	4021
+4022	4022
+4023	4023
+4024	4024
+4025	4025
+4026	4026
+4027	4027
+4028	4028
+4029	4029
+4030	4030
+4031	4031
+4032	4032
+4033	4033
+4034	4034
+4035	4035
+4036	4036
+4037	4037
+4038	4038
+4039	4039
+4040	4040
+4041	4041
+4042	4042
+4043	4043
+4044	4044
+4045	4045
+4046	4046
+4047	4047
+4048	4048
+4049	4049
+4050	4050
+4051	4051
+4052	4052
+4053	4053
+4054	4054
+4055	4055
+4056	4056
+4057	4057
+4058	4058
+4059	4059
+4060	4060
+4061	4061
+4062	4062
+4063	4063
+4064	4064
+4065	4065
+4066	4066
+4067	4067
+4068	4068
+4069	4069
+4070	4070
+4071	4071
+4072	4072
+4073	4073
+4074	4074
+4075	4075
+4076	4076
+4077	4077
+4078	4078
+4079	4079
+4080	4080
+4081	4081
+4082	4082
+4083	4083
+4084	4084
+4085	4085
+4086	4086
+4087	4087
+4088	4088
+4089	4089
+4090	4090
+4091	4091
+4092	4092
+4093	4093
+4094	4094
+4095	4095
+4096	4096
+4097	4097
+4098	4098
+4099	4099
+Result set:
+1	@ 1 day	one day
+2	@ 10 secs	ten secs
+# of result cols: 2
+Result set:
+2	bar
+disconnecting
diff --git a/test/output/quotes.source b/test/output/quotes.source
new file mode 100644
index 0000000..90a2b81
--- /dev/null
+++ b/test/output/quotes.source
@@ -0,0 +1,23 @@
+\! @abs_srcdir@/src/quotes-test
+connected
+Result set:
+Result set:
+foo
+param'quote
+Result set:
+foo
+param\backslash
+Result set:
+foo
+ends with backslash\
+Result set:
+Result set:
+foo
+param'quote
+Result set:
+foo
+param\backslash
+Result set:
+foo
+ends with backslash\
+disconnecting
diff --git a/test/output/select.source b/test/output/select.source
new file mode 100644
index 0000000..da62d64
--- /dev/null
+++ b/test/output/select.source
@@ -0,0 +1,8 @@
+\! @abs_srcdir@/src/select-test
+connected
+Result set:
+1
+2
+Result set:
+1	2	3	4	5	6	7	8	9	10	11	12	13	14	15	16	17	18	19	20	21	22	23	24	25	26	27	28	29	30	31	32	33	34	35	36	37	38	39	40	41	42	43	44	45	46	47	48	49	50	51	52	53	54	55	56	57	58	59	60	61	62	63	64	65	66	67	68	69	70	71	72	73	74	75	76	77	78	79	80	81	82	83	84	85	86	87	88	89	90	91	92	93	94	95	96	97	98	99	100	101	102	103	104	105	106	107	108	109	110	111	112	113	114	115	116	117	118	119	120	121	122	123	124	125	126	127	128	129	130	131	132	133	134	135	136	137	138	139	140	141	142	143	144	145	146	147	148	149	150	151	152	153	154	155	156	157	158	159	160	161	162	163	164	165	166	167	168	169	170	171	172	173	174	175	176	177	178	179	180	181	182	183	184	185	186	187	188	189	190	191	192	193	194	195	196	197	198	199	200	201	202	203	204	205	206	207	208	209	210	211	212	213	214	215	216	217	218	219	220	221	222	223	224	225	226	227	228	229	230	231	232	233	234	235	236	237	238	239	240	241	242	243	244	245	246	247	248	249	250	251	252	253	254	255	256	257	258	259	260	261	262	263	264	265	266	267	268	269	270	271	272	273	274	275	276	277	278	279	280	281	282	283	284	285	286	287	288	289	290	291	292	293	294	295	296	297	298	299	300	301	302	303	304	305	306	307	308	309	310	311	312	313	314	315	316	317	318	319	320	321	322	323	324	325	326	327	328	329	330	331	332	333	334	335	336	337	338	339	340	341	342	343	344	345	346	347	348	349	350	351	352	353	354	355	356	357	358	359	360	361	362	363	364	365	366	367	368	369	370	371	372	373	374	375	376	377	378	379	380	381	382	383	384	385	386	387	388	389	390	391	392	393	394	395	396	397	398	399	400	401	402	403	404	405	406	407	408	409	410	411	412	413	414	415	416	417	418	419	420	421	422	423	424	425	426	427	428	429	430	431	432	433	434	435	436	437	438	439	440	441	442	443	444	445	446	447	448	449	450	451	452	453	454	455	456	457	458	459	460	461	462	463	464	465	466	467	468	469	470	471	472	473	474	475	476	477	478	479	480	481	482	483	484	485	486	487	488	489	490	491	492	493	494	495	496	497	498	499	500	501	502	503	504	505	506	507	508	509	510	511	512	513	514	515	516	517	518	519	520	521	522	523	524	525	526	527	528	529	530	531	532	533	534	535	536	537	538	539	540	541	542	543	544	545	546	547	548	549	550	551	552	553	554	555	556	557	558	559	560	561	562	563	564	565	566	567	568	569	570	571	572	573	574	575	576	577	578	579	580	581	582	583	584	585	586	587	588	589	590	591	592	593	594	595	596	597	598	599	600	601	602	603	604	605	606	607	608	609	610	611	612	613	614	615	616	617	618	619	620	621	622	623	624	625	626	627	628	629	630	631	632	633	634	635	636	637	638	639	640	641	642	643	644	645	646	647	648	649	650	651	652	653	654	655	656	657	658	659	660	661	662	663	664	665	666	667	668	669	670	671	672	673	674	675	676	677	678	679	680	681	682	683	684	685	686	687	688	689	690	691	692	693	694	695	696	697	698	699	700	701	702	703	704	705	706	707	708	709	710	711	712	713	714	715	716	717	718	719	720	721	722	723	724	725	726	727	728	729	730	731	732	733	734	735	736	737	738	739	740	741	742	743	744	745	746	747	748	749	750	751	752	753	754	755	756	757	758	759	760	761	762	763	764	765	766	767	768	769	770	771	772	773	774	775	776	777	778	779	780	781	782	783	784	785	786	787	788	789	790	791	792	793	794	795	796	797	798	799	800	801	802	803	804	805	806	807	808	809	810	811	812	813	814	815	816	817	818	819	820	821	822	823	824	825	826	827	828	829	830	831	832	833	834	835	836	837	838	839	840	841	842	843	844	845	846	847	848	849	850	851	852	853	854	855	856	857	858	859	860	861	862	863	864	865	866	867	868	869	870	871	872	873	874	875	876	877	878	879	880	881	882	883	884	885	886	887	888	889	890	891	892	893	894	895	896	897	898	899	900	901	902	903	904	905	906	907	908	909	910	911	912	913	914	915	916	917	918	919	920	921	922	923	924	925	926	927	928	929	930	931	932	933	934	935	936	937	938	939	940	941	942	943	944	945	946	947	948	949	950	951	952	953	954	955	956	957	958	959	960	961	962	963	964	965	966	967	968	969	970	971	972	973	974	975	976	977	978	979	980	981	982	983	984	985	986	987	988	989	990	991	992	993	994	995	996	997	998	999	1000	1001	1002	1003	1004	1005	1006	1007	1008	1009	1010	1011	1012	1013	1014	1015	1016	1017	1018	1019	1020	1021	1022	1023	1024	1025	1026	1027	1028	1029	1030	1031	1032	1033	1034	1035	1036	1037	1038	1039	1040	1041	1042	1043	1044	1045	1046	1047	1048	1049	1050	1051	1052	1053	1054	1055	1056	1057	1058	1059	1060	1061	1062	1063	1064	1065	1066	1067	1068	1069	1070	1071	1072	1073	1074	1075	1076	1077	1078	1079	1080	1081	1082	1083	1084	1085	1086	1087	1088	1089	1090	1091	1092	1093	1094	1095	1096	1097	1098	1099	1100	1101	1102	1103	1104	1105	1106	1107	1108	1109	1110	1111	1112	1113	1114	1115	1116	1117	1118	1119	1120	1121	1122	1123	1124	1125	1126	1127	1128	1129	1130	1131	1132	1133	1134	1135	1136	1137	1138	1139	1140	1141	1142	1143	1144	1145	1146	1147	1148	1149	1150	1151	1152	1153	1154	1155	1156	1157	1158	1159	1160	1161	1162	1163	1164	1165	1166	1167	1168	1169	1170	1171	1172	1173	1174	1175	1176	1177	1178	1179	1180	1181	1182	1183	1184	1185	1186	1187	1188	1189	1190	1191	1192	1193	1194	1195	1196	1197	1198	1199	1200	1201	1202	1203	1204	1205	1206	1207	1208	1209	1210	1211	1212	1213	1214	1215	1216	1217	1218	1219	1220	1221	1222	1223	1224	1225	1226	1227	1228	1229	1230	1231	1232	1233	1234	1235	1236	1237	1238	1239	1240	1241	1242	1243	1244	1245	1246	1247	1248	1249	1250	1251	1252	1253	1254	1255	1256	1257	1258	1259	1260	1261	1262	1263	1264	1265	1266	1267	1268	1269	1270	1271	1272	1273	1274	1275	1276	1277	1278	1279	1280	1281	1282	1283	1284	1285	1286	1287	1288	1289	1290	1291	1292	1293	1294	1295	1296	1297	1298	1299	1300	1301	1302	1303	1304	1305	1306	1307	1308	1309	1310	1311	1312	1313	1314	1315	1316	1317	1318	1319	1320	1321	1322	1323	1324	1325	1326	1327	1328	1329	1330	1331	1332	1333	1334	1335	1336	1337	1338	1339	1340	1341	1342	1343	1344	1345	1346	1347	1348	1349	1350	1351	1352	1353	1354	1355	1356	1357	1358	1359	1360	1361	1362	1363	1364	1365	1366	1367	1368	1369	1370	1371	1372	1373	1374	1375	1376	1377	1378	1379	1380	1381	1382	1383	1384	1385	1386	1387	1388	1389	1390	1391	1392	1393	1394	1395	1396	1397	1398	1399	1400	1401	1402	1403	1404	1405	1406	1407	1408	1409	1410	1411	1412	1413	1414	1415	1416	1417	1418	1419	1420	1421	1422	1423	1424	1425	1426	1427	1428	1429	1430	1431	1432	1433	1434	1435	1436	1437	1438	1439	1440	1441	1442	1443	1444	1445	1446	1447	1448	1449	1450	1451	1452	1453	1454	1455	1456	1457	1458	1459	1460	1461	1462	1463	1464	1465	1466	1467	1468	1469	1470	1471	1472	1473	1474	1475	1476	1477	1478	1479	1480	1481	1482	1483	1484	1485	1486	1487	1488	1489	1490	1491	1492	1493	1494	1495	1496	1497	1498	1499	1500	1501	1502	1503	1504	1505	1506	1507	1508	1509	1510	1511	1512	1513	1514	1515	1516	1517	1518	1519	1520	1521	1522	1523	1524	1525	1526	1527	1528	1529	1530	1531	1532	1533	1534	1535	1536	1537	1538	1539	1540	1541	1542	1543	1544	1545	1546	1547	1548	1549	1550	1551	1552	1553	1554	1555	1556	1557	1558	1559	1560	1561	1562	1563	1564	1565	1566	1567	1568	1569	1570	1571	1572	1573	1574	1575	1576	1577	1578	1579	1580	1581	1582	1583	1584	1585	1586	1587	1588	1589	1590	1591	1592	1593	1594	1595	1596	1597	1598	1599	1600
+disconnecting
diff --git a/test/output/stmthandles.source b/test/output/stmthandles.source
new file mode 100644
index 0000000..efcf148
--- /dev/null
+++ b/test/output/stmthandles.source
@@ -0,0 +1,70 @@
+\! @abs_srcdir@/src/stmthandles-test
+connected
+10 statements allocated...
+20 statements allocated...
+30 statements allocated...
+40 statements allocated...
+50 statements allocated...
+60 statements allocated...
+70 statements allocated...
+80 statements allocated...
+90 statements allocated...
+100 statements allocated...
+10 statements executed...
+20 statements executed...
+30 statements executed...
+40 statements executed...
+50 statements executed...
+60 statements executed...
+70 statements executed...
+80 statements executed...
+90 statements executed...
+100 statements executed...
+Result set:
+stmt no 1
+Result set:
+stmt no 11
+Result set:
+stmt no 21
+Result set:
+stmt no 31
+Result set:
+stmt no 41
+Result set:
+stmt no 51
+Result set:
+stmt no 61
+Result set:
+stmt no 71
+Result set:
+stmt no 81
+Result set:
+stmt no 91
+
+Testing interleaving operations on multiple prepared statements
+# of result cols: 1
+# of result cols: 2
+# of result cols: 3
+# of result cols: 4
+# of result cols: 5
+Result set:
+stmt no 0
+stmt no 0
+stmt no 0
+Result set:
+stmt no 1	col 0
+stmt no 1	col 0
+stmt no 1	col 0
+Result set:
+stmt no 2	col 0	col 1
+stmt no 2	col 0	col 1
+stmt no 2	col 0	col 1
+Result set:
+stmt no 3	col 0	col 1	col 2
+stmt no 3	col 0	col 1	col 2
+stmt no 3	col 0	col 1	col 2
+Result set:
+stmt no 4	col 0	col 1	col 2	col 3
+stmt no 4	col 0	col 1	col 2	col 3
+stmt no 4	col 0	col 1	col 2	col 3
+disconnecting
diff --git a/test/src/common.c b/test/src/common.c
index 2423ad0..1563392 100644
--- a/test/src/common.c
+++ b/test/src/common.c
@@ -31,8 +31,14 @@ test_connect_ext(char *extraparams)
 	SQLSMALLINT strl;
 	SQLCHAR dsn[1024];
 
+#ifdef WIN32
+	snprintf(dsn, sizeof(dsn), "Driver=PostgreSQL test;"
+			 "Server=localhost;Database=contrib_regression;%s",
+			 extraparams ? extraparams : "");
+#else
 	snprintf(dsn, sizeof(dsn), "DSN=psqlodbc_test_dsn;%s",
 			 extraparams ? extraparams : "");
+#endif
 
 	SQLAllocHandle(SQL_HANDLE_ENV, SQL_NULL_HANDLE, &env);
 
diff --git a/test/src/deprecated-test.c b/test/src/deprecated-test.c
index 0883434..8c52eae 100644
--- a/test/src/deprecated-test.c
+++ b/test/src/deprecated-test.c
@@ -86,7 +86,14 @@ main(int argc, char **argv)
 		exit(1);
 	}
 
-	rc = SQLDriverConnect(conn2, NULL, "DSN=psqlodbc_test_dsn;", SQL_NTS,
+#ifdef WIN32
+	snprintf(buffer, sizeof(buffer), "Driver=PostgreSQL test;"
+			 "Server=localhost;Database=contrib_regression;");
+#else
+	snprintf(buffer, sizeof(buffer), "DSN=psqlodbc_test_dsn;");
+#endif
+
+	rc = SQLDriverConnect(conn2, NULL, buffer, SQL_NTS,
 						  NULL, 0, &val,
 						  SQL_DRIVER_COMPLETE);
 	if (!SQL_SUCCEEDED(rc))
diff --git a/test/win.mak b/test/win.mak
new file mode 100644
index 0000000..7cb63c8
--- /dev/null
+++ b/test/win.mak
@@ -0,0 +1,82 @@
+#
+# File:                 win.mak
+#
+# Description:          Makefile for regression tests on Windows
+#                       (can be built using platform SDK's buildfarm)
+#
+# Usage:                NMAKE /f win.mak [ installcheck ]
+#
+# Comments:             Created by Michael Paquier, 2014-05-21
+#
+
+# Environment checks
+!IF "$(CPU)" == ""
+!MESSAGE Making 64bit DLL...
+!MESSAGE You should set the CPU environment variable
+!MESSAGE to distinguish your OS
+!ENDIF
+
+!IFNDEF PG_BIN
+PG_LIB=C:\develop\bin\$(CPU)
+!MESSAGE Using default PostgreSQL Binary directory: $(PG_BIN)
+!ENDIF
+
+# List of test objects
+TESTOBJS = src/connect-test.obj \
+	src/stmthandles-test.obj \
+	src/select-test.obj \
+	src/commands-test.obj \
+	src/multistmt-test.obj \
+	src/getresult-test.obj \
+	src/prepare-test.obj \
+	src/params-test.obj \
+	src/notice-test.obj \
+	src/arraybinding-test.obj \
+	src/insertreturning-test.obj \
+	src/dataatexecution-test.obj \
+	src/boolsaschar-test.obj \
+	src/cvtnulldate-test.obj \
+	src/alter-test.obj \
+	src/quotes-test.obj \
+	src/cursors-test.obj \
+	src/positioned-update-test.obj \
+	src/catalogfunctions-test.obj \
+	src/bindcol-test.obj \
+	src/lfconversion-test.obj \
+	src/cte-test.obj \
+	src/deprecated-test.obj \
+	src/error-rollback-test.obj \
+	src/diagnostic-test.obj
+
+# The list of tests is extracted from the object list above. This could
+# be cleaner but it is more stable than the reverse operation.
+TESTS = $(TESTOBJS:src/=)
+TESTS = $(TESTS:-test.obj=)
+TESTS = sampletables $(TESTS)
+
+# Flags
+CLFLAGS=/D WIN32
+LINKFLAGS=/link odbc32.lib odbccp32.lib
+
+# Build an executable for each test.
+.c.obj:
+	cl $*.c src/common.obj $(CLFLAGS) $(LINKFLAGS)
+	-@echo \! @abs_srcdir@/$* > $(*:-test=).source
+	-@mv *.exe *.obj src/
+	-@mv $(*:-test=).source input/
+
+all: common.obj $(TESTOBJS)
+
+common.obj:
+	cl /c src/common.c $(CLFLAGS)
+	-@mv common.obj src/
+
+# Run regression tests
+installcheck:
+	cmd /c $(PG_BIN)\pg_regress --inputdir=. --psqldir="$(PG_BIN)" \
+	    --dbname="contrib_regression" \
+	    $(TESTS)
+
+clean:
+	del src\*.exe
+	del src\*.obj
diff --git a/test/win_registry_key.reg b/test/win_registry_key.reg
new file mode 100644
index 0000000..4b03de5
Binary files /dev/null and b/test/win_registry_key.reg differ
